// ==============================================================
//                 ORBITER MODULE: ShuttlePB
//                  Part of the ORBITER SDK
//          Copyright (C) 2002-2004 Martin Schweiger
//                   All rights reserved
//
// ShuttlePB.cpp
// Control module for ShuttlePB vessel class
//
// Notes:
// This is an example for a "minimal" vessel implementation which
// only overloads the clbkSetClassCaps method to define vessel
// capabilities and otherwise uses the default VESSEL class
// behaviour.
// ==============================================================

#define STRICT
#define ORBITER_MODULE

#define ENG 				1	
#define GEAR				2	
#define BRAKE               3
#define ENGSTART			4
#define ENGSTOP				5
#define AFTER				6
#define WARNING				7
#define ENGEXT				8
#define ATTFIRE				9
#define WARNING_ALT			10
#define WIND				11
#define PULL_UP				12
#define TOO_LOW_G			13
#define TOO_LOW_F			14
#define TOO_LOW_T			15

#include <orbitersdk.h>
#include <cstdio>
#include <cmath>
#include <iostream>

#include <string>
#include "OrbiterSoundSDK35.h"

#include <stdio.h>
#include <stdlib.h>

using namespace std;


// ==============================================================
// Some vessel parameters
// ==============================================================
const double PB_FUELMASS = 55680.0;
const double PB_FUELMASS1 = 20000.0;
const double PB_FUELMASS2 = 20000.0;
const double PB_FUELMASS3 = 20000.0;

const double PB_ISP = 400000.0;//50000.0
const double PB_ISP2 = 10000000.0;
const double PB_MAXMAINTH =0;
const double PB_MAXHOVERTH =0;
const double PB_MAXRCSTH = 9.9e4;
double iop = 0;
double st = 0;
double pld = 0;
double cen = 0;
double vario_proc = 0;
double vario = 0;
double vario81 = 0;
double gear_proc = 0;
double gear_cover = 0;
double gear_procl = 0;
double speedbrake = 0;
double flaps = 0;//landing lights
double first = 0;
double variofirst = 0;
double exproc = 0;
double varioexproc = 0;
double Lights = 0;
double switched = 0;
double aoa;

double dil = 0;
double vdil = 0;
double eng_pitch = 22000;

double MFD_USERDEF;
double after = 0;
double Engine = 0;
double start = 0;
double full = 0.001;
double i = 0;
double i1 = 0;
double i2 = 0;
double i3 = 0;
double i4 = 0;
double i5 = 0;
double i7 = 0;
double i9 = 0;
double vi9 = 0;
double i14 = 0;//////////////
double i15 = 0;
double i16 = 0;
double iheight = 0;
double i2height = 0;
double i3height = 0;
double mi14 = 0;//////////////
double dmi14 = 0;//////////////

double i21 = 0;
double fuel_change = 0;//double i22 = 0;
double i23 = 0;
double i24 = 0;

double i25 = 0;
double i26 = 0;
double mi27 = 0;
double mi28 = 0;
double i77 = 0;

double last_fuel_change = 0;//double i30 = 0;

double i1a = 0;
double i2a = 0;
double i3a = 0;
double i4a = 0;
double i5a = 0;
double s1 = 0;
double s2 = 0;
double s3 = 0;
double s4 = 0;
double s5 = 0;

double si = 0;
double si1 = 0;
double si2 = 0;
double si3 = 0;
double si4 = 0;
double si5 = 0;
double si7 = 0;
double si9 = 0;
double si1a = 0;
double si2a = 0;
double si3a = 0;
double si4a = 0;
double si5a = 0;
double ss1 = 0;
double ss2 = 0;
double ss3 = 0;
double ss4 = 0;
double ss5 = 0;

double msi2 = 0;
double msi3 = 0;
double msi4 = 0;
double msi5 = 0;
double msi2a = 0;
double msi3a = 0;
double msi1 = 0;
double mss1 = 0;
double mss2 = 0;
double mss3 = 0;
double mss4 = 0;
double mss5 = 0;
double msi1a = 0;
double msi4a = 0;
double msi5a = 0;

double ga = 0;
double diff = 0.1;
double k3;
double k3h;
int k4;
double ks3;
double mks3;
double dmks3;
int ks4;
int mks4;
char k3buffer [33];
char mk3buffer [33];
char ks3buffer [33];//////////////////
char mks3buffer [33];//////////////////
double amet = 0;
double dee = 0;
double dees = 0;
double mdees = 0;
double power_proc = 0;
double percentpower_proc = 0;
double egtpower_proc = 0;
double fuel_proc = 0;
double shift = i21;
double meter = 0;
double ilast = 0;
double increase = 0;

double change1 = 0;
double change2 = 0;
double tpp = 0;

double x = -120;
UINT animactive;

UINT animactivel;

UINT animactive2;

UINT animactive3;

UINT animactive4;

UINT animactive5;
UINT animactive6;
UINT animactive7;
UINT animactive8;

UINT anim_turn;

UINT anim_power;
UINT egtanim_power;
UINT percentanim_power;
UINT anim_bank;
UINT anim_pitch;
UINT anim_machdial;
UINT anim_machdial1;
UINT anim_machdial2;
UINT anim_machdial3;
UINT anim_machdial4;
UINT anim_machdial5;

bool clbkVCMouseEvent (int id, int event, VECTOR3 &p);

 VECTOR3 offset = {0,-0.4,4.3};//0,-0.4,4.3//const
const VECTOR3 offsetnose = {-0.8,-1.4,-13.0};

const VECTOR3 offsetalt = {-1.335, -0.89, 5.19};//0.092,-0.1,4.3
							//-1.316007, -0.8731193, 5.12	//Top Right-1.33002, -0.5087858, 5.12
const VECTOR3 offsetaoa = {-0.095,-0.105,4.3};

const VECTOR3 offsetdirect = {-1.84, -1.20,5.14};//4.3
const VECTOR3 offsetspeed = {-2.29, -0.54,5.12};
const VECTOR3 offsetbank = {-1.84, -0.485,5.04};//-1.81, -0.425,4.9
const VECTOR3 offsetmach = {-2.24, -0.93,5.05};
const VECTOR3 offsetcentre = {-0.22, -1.0,5.05};
const VECTOR3 offsetautopilot = {-0.22, -2.0,4.98};//-0.22, -0.3,4.98
const VECTOR3 offsetscreen = {-0.0, -2.00,4.86};//left=-2.57, -1.45,5.15 //copy2/centre left=-0.36, -1.62,5.11
const VECTOR3 offsetheight = {-1.335, -0.52, 5.10};
const VECTOR3 offsetbank2 = {-1.03, -0.49, 4.972};
const VECTOR3 offsetvor = {-2.25, -1.26, 5.13};//-1.44, -1.32, 5.14
VECTOR3 offsetcog = {0, 0, 0};
VECTOR3 vertspeed = {0, 0, 0};
 
 
AIRFOILHANDLE AIRFOILHANDLE1;		
//THRUSTER_HANDLE thg_pitch[2];
//THRUSTER_HANDLE thg_bank[2];
THRUSTER_HANDLE th_main;
THRUSTER_HANDLE th_after;
THRUSTER_HANDLE th_retro;

THRUSTER_HANDLE th_hover[2];
THRUSTER_HANDLE th_trail;
THRUSTER_HANDLE th_rcs_up[2], th_rcs_down[2],  th_rcs_left[2],  th_rcs_right[2],  th_rcs_yawl[2],    th_rcs_yawr[2];

BEACONLIGHTSPEC beacon1;    
BEACONLIGHTSPEC beacon2;   
BEACONLIGHTSPEC beacon3;
BEACONLIGHTSPEC beacon4;//orange
BEACONLIGHTSPEC beacon5;//orange
BEACONLIGHTSPEC beacon6;//orange
BEACONLIGHTSPEC beacon7;//llight lw
BEACONLIGHTSPEC beacon8;//llight lg
BEACONLIGHTSPEC beacon9;//llight rw
BEACONLIGHTSPEC beacon10;//llight rg






MESHHANDLE f150;//concorde
MESHHANDLE f151;//nose

MESHHANDLE f152;//
MESHHANDLE f153;
MESHHANDLE f154;
MESHHANDLE f155;
MESHHANDLE f156;
MESHHANDLE f157;
MESHHANDLE f158;
MESHHANDLE f159;
MESHHANDLE f160;
MESHHANDLE f161;
MESHHANDLE f180;//VOR
//MESHHANDLE f181;//Autopilot
//MESHHANDLE f182;//panel
//MESHHANDLE f183;//psngr3

MESHHANDLE f162;
MESHHANDLE f163;
MESHHANDLE f164;
MESHHANDLE f165;
MESHHANDLE f166;
MESHHANDLE f167;
MESHHANDLE f168;
MESHHANDLE f169;//VOR_n

MESHHANDLE f170;//height_n
MESHHANDLE f171;//bank2_n
MESHHANDLE f172;//_n
MESHHANDLE f173;//Autopilot_n
//MESHHANDLE f164;
//MESHHANDLE f165;

// 1. vertical lift component (wings and body)

void VLiftCoeff (double aoa, double M, double Re, double *cl, double *cm, double *cd)
{
	static const double step = RAD*15.0;
	static const double istep = 1.0/step;
	static const int nabsc = 25;
	static const double CL[nabsc] = {0.1, 0.17, 0.2, 0.2, 0.17, 0.1, 0, -0.11, -0.24, -0.38,  -0.5,  -0.5, -0.02, 0.6355,    0.63,   0.46, 0.28, 0.13, 0.0, -0.16, -0.26, -0.29, -0.24, -0.1, 0.1};
	static const double CM[nabsc] = {  0,    0,   0,   0,    0,   0, 0,     0,    0,0.002,0.004, 0.0025,0.0012,      0,-0.0012,-0.0007,    0,    0,   0,     0,     0,     0,     0,    0,   0};
	// lift and moment coefficients from -180 to 180 in 15 degree steps.
	// This uses a documented lift slope of 0.0437/deg, everything else is rather ad-hoc

	aoa += PI;
	int idx = max (0, min (23, (int)(aoa*istep)));
	double d = aoa*istep - idx;
	*cl = CL[idx] + (CL[idx+1]-CL[idx])*d;
	*cm = CM[idx] + (CM[idx+1]-CM[idx])*d;
	*cd = 0.06 + oapiGetInducedDrag (*cl, 2.266, 0.6);
	}

// 2. horizontal lift component (vertical stabiliser and body)

void HLiftCoeff (double beta, double M, double Re, double *cl, double *cm, double *cd)
{
	static const double step = RAD*22.5;
	static const double istep = 1.0/step;
	static const int nabsc = 17;
	static const double CL[nabsc] = {0, 0.2, 0.3, 0.2, 0, -0.2, -0.3, -0.2, 0, 0.2, 0.3, 0.2, 0, -0.2, -0.3, -0.2, 0};

	beta += PI;
	int idx = max (0, min (15, (int)(beta*istep)));
	double d = beta*istep - idx;
	*cl = CL[idx] + (CL[idx+1]-CL[idx])*d;
	*cm = 0.0;
	*cd = 0.02 + oapiGetInducedDrag (*cl, 1.5, 0.6);
}


// ==============================================================
// Shuttle-PB class interface
// ==============================================================

class ShuttlePB: public VESSEL2 {
public:
	ShuttlePB (OBJHANDLE hVessel, int flightmodel);
	//	: VESSEL2 (hVessel, flightmodel) {}
	void clbkSetClassCaps (FILEHANDLE cfg);
	void DefineAnimations(void);
	void Steering();
	void Lighting();
	void clbkPostCreation (void);
    void clbkPostStep (double simt, double simdt, double mjd);
    int  clbkConsumeBufferedKey (DWORD key, bool down, char *kstate);
  ~ShuttlePB();//added 
int ShiftHoverBalance;////added

  UINT anim_wheel;
    UINT anim_gear;
	UINT anim_gearcover;
    UINT anim_gearlever;
	 UINT anim_vario;
	 UINT anim_vario1;
	 UINT anim_variolever;
	 UINT anim_varioVC;

    UINT anim_rudder;
   UINT anim_elevator;
    UINT anim_laileron;
    UINT anim_raileron;

    UINT anim_speedbrake;
    UINT anim_flaps;
    
	
    UINT anim_wheel0;//Altimeter
    UINT anim_hwheel;//height meter
	UINT anim_hwheel2;//height meter
	UINT anim_wheel1;
    UINT anim_wheel2;
    UINT anim_wheel3;
    UINT anim_wheel4;
    UINT anim_wheel5;

	UINT anim_wheels0;
    UINT anim_wheels1;
    UINT anim_wheels2;
    UINT anim_wheels3;
    UINT anim_wheels4;
    UINT anim_wheels5;
    
    UINT anim_dial1;
    UINT anim_dial2;
	 UINT anim_dial10;//vert speed
	UINT anim_vordial2;
	 
	UINT anim_fuel;
	 UINT anim_fuel2;
	 UINT anim_fuel3;
	 UINT anim_fuel4;

	UINT anim_cogmeter;
	
    bool clbkLoadVC (int id);
    //bool clbkLoadVC (int id1);
    MGROUP_TRANSFORM *pitch1;//added 
	 MGROUP_TRANSFORM *wheel1;//added last
	 MGROUP_TRANSFORM *gwheel1;//added last
    int MySoundID;	
	
	PROPELLANT_HANDLE hpr1 ;
	PROPELLANT_HANDLE hpr2 ;
	PROPELLANT_HANDLE hpr3 ;
	PROPELLANT_HANDLE hpr4 ;

};

ShuttlePB::ShuttlePB (OBJHANDLE hVessel, int flightmodel)
		: VESSEL2 (hVessel, flightmodel)
{
	
	// preload meshes
	
   
    f150                 = oapiLoadMeshGlobal ("JMW\\Concorde");//Concorde
    f151				 = oapiLoadMeshGlobal ("JMW\\Old\\Concorde_Nose");
	
	f152                 = oapiLoadMeshGlobal ("JMW\\Old\\K-F-15A-Cpit");
    f153                 = oapiLoadMeshGlobal ("JMW\\Old\\K-F-15A-Cpit-Alt");
    f154                 = oapiLoadMeshGlobal ("JMW\\Old\\K-F14A-Cpit-Bank");
	f155                 = oapiLoadMeshGlobal ("JMW\\Old\\K-F-15A-Cpit-Direct");
	f156                 = oapiLoadMeshGlobal ("JMW\\Old\\Concorde-Cpit-MachSpeed");
    f157				 = oapiLoadMeshGlobal ("JMW\\Old\\K-F-15A-Cpit-Speed");
	f158				 = oapiLoadMeshGlobal ("JMW\\Old\\Concorde_Centre");
	f159				 = oapiLoadMeshGlobal ("JMW\\Old\\Status_Screen");
	f160				 = oapiLoadMeshGlobal ("JMW\\Old\\K-F-15A-Cpit-Hgt");
	f161				 = oapiLoadMeshGlobal ("JMW\\Old\\K-F14A-Cpit-Bank2");
	f180				 = oapiLoadMeshGlobal ("JMW\\Old\\Concorde_Cpit_VOR");
	//f181				 = oapiLoadMeshGlobal ("JMW\\Old\\Autopilot");

	f162                 = oapiLoadMeshGlobal ("JMW\\Old\\K-F-15A-Cpit_n");
	f163                 = oapiLoadMeshGlobal ("JMW\\Old\\K-F-15A-Cpit-Alt_n");
    f164                 = oapiLoadMeshGlobal ("JMW\\Old\\K-F14A-Cpit-Bank_n");
    f165                 = oapiLoadMeshGlobal ("JMW\\Old\\K-F-15A-Cpit-Direct_n");
	f166                 = oapiLoadMeshGlobal ("JMW\\Old\\Concorde-Cpit-MachSpeed_n");
	f167                 = oapiLoadMeshGlobal ("JMW\\Old\\K-F-15A-Cpit-Speed_n");
	f168				 = oapiLoadMeshGlobal ("JMW\\Old\\Concorde_Centre_n");
	f169				 = oapiLoadMeshGlobal ("JMW\\Old\\Concorde_Cpit_VOR_n");
	f170				 = oapiLoadMeshGlobal ("JMW\\Old\\K-F-15A-Cpit-Hgt_n");
	f171				 = oapiLoadMeshGlobal ("JMW\\Old\\K-F14A-Cpit-Bank2_n");
	//f172				 = oapiLoadMeshGlobal ("JMW\\Old\\Autopilot_n");
	DefineAnimations ();
}


void ShuttlePB::clbkPostCreation (void)
{

MySoundID=ConnectToOrbiterSoundDLL3(GetHandle());

ReplaceStockSound3(MySoundID,"Sound\\Vessel\\K-Test-Car\\K-Test-Car.wav",	REPLACE_MAIN_THRUST);
RequestLoadVesselWave3(MySoundID,ENGEXT,"Sound\\Concorde\\EngExt.wav",BOTHVIEW_FADED_CLOSE);
RequestLoadVesselWave3(MySoundID,ENG,"Sound\\Concorde\\Concorde.wav",BOTHVIEW_FADED_MEDIUM);
RequestLoadVesselWave3(MySoundID,ENGSTOP,"Sound\\Concorde\\EngStop.wav",BOTHVIEW_FADED_CLOSE);////////ADDED
RequestLoadVesselWave3(MySoundID,ENGSTART,"Sound\\Concorde\\EngStart.wav",BOTHVIEW_FADED_CLOSE);//////
RequestLoadVesselWave3(MySoundID,AFTER,"Sound\\Concorde\\Concorde_After.wav",BOTHVIEW_FADED_MEDIUM);
RequestLoadVesselWave3(MySoundID,BRAKE,"Sound\\Concorde\\Brake.wav",BOTHVIEW_FADED_CLOSE);
RequestLoadVesselWave3(MySoundID,WARNING,"Sound\\Concorde\\Warning.wav",INTERNAL_ONLY);
RequestLoadVesselWave3(MySoundID,WARNING_ALT,"Sound\\Concorde\\Warning_Alt.wav",INTERNAL_ONLY);
RequestLoadVesselWave3(MySoundID,PULL_UP,"Sound\\Concorde\\pull_up.wav",INTERNAL_ONLY);
RequestLoadVesselWave3(MySoundID,TOO_LOW_G,"Sound\\Concorde\\too_low_gear_up.wav",INTERNAL_ONLY);
//RequestLoadVesselWave3(MySoundID,TOO_LOW_F,"Sound\\Concorde\\too_low_flaps_up.wav",INTERNAL_ONLY);
RequestLoadVesselWave3(MySoundID,TOO_LOW_T,"Sound\\Concorde\\too_low_terrain.wav",INTERNAL_ONLY);
RequestLoadVesselWave3(MySoundID,ATTFIRE,"Sound\\Concorde\\attfire.wav",INTERNAL_ONLY);
RequestLoadVesselWave3(MySoundID,GEAR,"Sound\\Concorde\\Gear.wav",BOTHVIEW_FADED_CLOSE);
//RequestLoadVesselWave3(MySoundID,FLAPS,"Sound\\Concorde\\flaps.wav",BOTHVIEW_FADED_CLOSE);
RequestLoadVesselWave3(MySoundID,WIND,"Sound\\Concorde\\wind_general.wav",INTERNAL_ONLY);

SoundOptionOnOff3(MySoundID,PLAYWINDAIRSPEED, TRUE);

SoundOptionOnOff3(MySoundID,PLAYMAINTHRUST,FALSE);

SoundOptionOnOff3(MySoundID,PLAYHOVERTHRUST,FALSE);

SoundOptionOnOff3(MySoundID,PLAYCOUNTDOWNWHENTAKEOFF,FALSE);

SoundOptionOnOff3(MySoundID,PLAYCABINAIRCONDITIONING,TRUE);

SoundOptionOnOff3(MySoundID,PLAYCABINRANDOMAMBIANCE,FALSE);

SoundOptionOnOff3(MySoundID,PLAYRADIOATC,TRUE);

SoundOptionOnOff3(MySoundID,DISPLAYTIMER,FALSE);

}


// --------------------------------------------------------------
// Set the capabilities of the vessel class
// --------------------------------------------------------------

void ShuttlePB::clbkSetClassCaps (FILEHANDLE cfg)
{
	// THRUSTER_HANDLE th_main;

	// physical specs
	SetSize (62);//30
	SetEmptyMass (66500.0);
	SetCW (0.3, 0.3, 0.6, 0.9);
	SetWingAspect (1.5);//1.7/////////03/03/09
	SetWingEffectiveness (6.1);//3.1//then 4.1/////////////////////////////
	SetCrossSections (_V(53.0,186.9,25.9));//5,5,15/////////03/03/09//53.0,186.9,25.9//96.52,259.28,15.83 last//vlast=30.51,134.41,26.15
	SetRotDrag (_V(1.5,1.5,1.5));//3.5,3.5,3.5/////////03/03/09
	if (GetFlightModel() >= 1) {
		SetPitchMomentScale (1e-4);//1e-4
		SetBankMomentScale (1e-4);//1e-4
	}
	SetPMI (_V(15.5,22.1,7.7));//(_V(15.5,22.1,7.7))
	SetTrimScale (0.05);//0.05
	SetCameraOffset (_V(-0.4,7.0,22));
	
	SetTouchdownPoints (_V(0, -2.185396,  11.09318), _V(-3.359408, -2.088643, -7.289797), _V(3.359408, -2.088643, -7.289797));//(_V(0,-2.3,9), _V(-4,-2.33,-5), _V(4,-2.33,-5))

	// **************************** aerodynamics ***********************************

	AIRFOILHANDLE1 = CreateAirfoil2 (LIFT_VERTICAL, _V(0,0,-0.061), VLiftCoeff, 16.5, 270, 2.266);//-0.561 VLiftCoeff, 16.5, 270, 2.266)
	CreateAirfoil (LIFT_HORIZONTAL, _V(0,0,-4), HLiftCoeff, 20,  50, 1.5);//V(0,0,-4

					//EditAirfoil (AIRFOILHANDLE1,0x01,_V(0,0,-0.061),VLiftCoeff, 17.5, 270, 2.266);



	CreateControlSurface (AIRCTRL_ELEVATOR,     7, 0.7, _V(   0,0,-17), AIRCTRL_AXIS_XPOS,anim_elevator);
	CreateControlSurface (AIRCTRL_RUDDER,       2, 0.5, _V(   0,2,-15), AIRCTRL_AXIS_YPOS,anim_rudder);//   0,2,-15
	CreateControlSurface (AIRCTRL_AILERON,      4.8, 0.2, _V( 17.8,0,-17.8), AIRCTRL_AXIS_XPOS,anim_raileron);
	CreateControlSurface (AIRCTRL_AILERON,      4.8, 0.2, _V(-17.8,0,-17.8), AIRCTRL_AXIS_XNEG,anim_laileron);
	CreateControlSurface (AIRCTRL_ELEVATORTRIM, 7, 0.4, _V(   0,0,-15), AIRCTRL_AXIS_XPOS);//5, 0.1, _V(   0,0,-15)
    //CreateControlSurface (AIRCTRL_FLAP,         5, 5, _V( 0,0,-1), AIRCTRL_AXIS_XPOS,anim_flaps);
	
	CreateVariableDragElement( &speedbrake, 8.0, _V(0,0,0) );

	CreateVariableDragElement (&gear_proc, 0.8, _V(0, -1, 0));/////////////////
	CreateVariableDragElement (&vario81, 0.5, _V(0, -1, 0));//&vario81, 1.0, _V(0, -1, 0)
	
	// propellant resources
	 PROPELLANT_HANDLE hpr = CreatePropellantResource (PB_FUELMASS);
					hpr1 = CreatePropellantResource (PB_FUELMASS1);
					hpr2 = CreatePropellantResource (PB_FUELMASS2);
					hpr3 = CreatePropellantResource (PB_FUELMASS3);
	
	SURFHANDLE tex_main = oapiRegisterExhaustTexture ("Concorde-Exhaust");
	SURFHANDLE tex_after = oapiRegisterExhaustTexture ("Concorde-After");

	// ***************** thruster definitions *******************

	PARTICLESTREAMSPEC contrail_main = {
	 //NU  size  rate speed  Disp  life  grow  Dens
		0, 0.04, 500,  50,   0.2,  0.1,   30,   0.011, PARTICLESTREAMSPEC::DIFFUSE,//0, 0.34, 165, 19, 0.019, 0.111, 1.11, 1.11, PARTICLESTREAMSPEC::DIFFUSE,
		PARTICLESTREAMSPEC::LVL_PSQRT, 0, 2,
		PARTICLESTREAMSPEC::ATM_PLOG, 1e-4, 1
	};
	//////////////////////////////
	//NU size  rate speed  Disp	  life  grow  Dens
	//0,  0.3, 565, 12,   0.019, 0.121, 3.11, 0.1, PARTICLESTREAMSPEC::DIFFUSE,
	////////////////////////////
	PARTICLESTREAMSPEC contrail_hover = {
		0, 0.333, 60, 212, 0.01, 30, 1.33, 2.0, PARTICLESTREAMSPEC::DIFFUSE,//0, 0.033, 511, 112, 0.01, 42, 1.333, 2.0, PARTICLESTREAMSPEC::EMISSIVE
		
		PARTICLESTREAMSPEC::LVL_PSQRT, 0, 2,
		PARTICLESTREAMSPEC::ATM_PLOG, 1e-4, 1
	};
	
	th_main = CreateThruster (_V(0,0,-16.3), _V(0,0,1), PB_MAXMAINTH, hpr, PB_ISP);//-5
	th_after =  CreateThruster (_V(0,0,-16.3), _V(0,0,1), PB_MAXMAINTH, hpr, PB_ISP);
	th_trail = CreateThruster (_V(0,0,-5), _V(0,0,1), PB_MAXMAINTH, hpr, PB_ISP);
	th_after =  CreateThruster (_V(0,0,-16.3), _V(0,0,1), PB_MAXMAINTH, hpr, PB_ISP);
	th_retro =  CreateThruster (_V(0,0,-5), _V(0,0,1), PB_MAXMAINTH, hpr, PB_ISP);
	
	th_hover[0] = CreateThruster (_V(0,-1,-14.5), _V(0,1,0), PB_MAXHOVERTH, hpr, PB_ISP2);
	th_hover[1] = CreateThruster ( _V(0,-1,14.5), _V(0,1,0), PB_MAXHOVERTH, hpr, PB_ISP2);
	
	//thg_bank[0] = CreateThruster (_V(-4.5,-1,0), _V(0,1,0), PB_MAXMAINTH, hpr, PB_ISP);
	//thg_bank[1] = CreateThruster ( _V(4.5,-1,0), _V(0,1,0), PB_MAXMAINTH, hpr, PB_ISP);
	
	//CreateThrusterGroup (thg_pitch, 2, THGROUP_ATT_UP);
	//CreateThrusterGroup (thg_bank,  2, THGROUP_ATT_DOWN);
	
	CreateThrusterGroup (&th_main,  1, THGROUP_MAIN);
	CreateThrusterGroup (&th_after,  1, THGROUP_USER );//after;
	CreateThrusterGroup (th_hover, 2, THGROUP_HOVER);
	CreateThrusterGroup (&th_retro,  1, THGROUP_RETRO);
	//CreateThrusterGroup (&th_hover, 1, THGROUP_ATT_UP);
	//CreateThrusterGroup (&th_hover, 1, THGROUP_ATT_DOWN);
	
	AddExhaust (th_main, 2.4, 0.55, _V(-6.070018,  1.076913, -16.3), _V(0,0,-1) , tex_main);
										//-6.070018,  1.076913, -17.3849
	AddExhaust (th_main, 2.4, 0.55, _V(-4.734217,  1.097051, -16.3), _V(0,0,-1) , tex_main);
	AddExhaust (th_main, 2.4, 0.55, _V( 4.734217,  1.097051, -16.3), _V(0,0,-1) , tex_main);
	AddExhaust (th_main, 2.4, 0.55, _V( 6.070018,  1.076913, -16.3), _V(0,0,-1) , tex_main);

    AddExhaust (th_after, 3.4, 0.55, _V(-6.070018,  1.076913, -16.3), _V(0,0,-1) , tex_after);//3,0.1,-14//0,0,-1
	AddExhaust (th_after, 3.4, 0.55, _V(-4.734217,  1.097051, -16.3), _V(0,0,-1) , tex_after);//-3,0.1,-14//0,0,-1
	AddExhaust (th_after, 3.4, 0.55, _V(4.734217,  1.097051, -16.3), _V(0,0,-1) , tex_after);
	AddExhaust (th_after, 3.4, 0.55, _V(6.070018,  1.076913, -16.3), _V(0,0,-1) , tex_after);
	
	//AddExhaustStream (th_hover[0], _V(0,-4,-14.5), &contrail_main);//(thg_hover, _V(0,-0.1580385,-5.802197), &contrail_main)
   // AddExhaustStream (th_hover[1], _V(0,-4,14.5), &contrail_main);
	//ADDED
	AddExhaustStream (th_after, _V(-6.070018,  1.076913, -16.3), &contrail_main);
	AddExhaustStream (th_after, _V(-4.734217,  1.097051, -16.3), &contrail_main);
	AddExhaustStream (th_after, _V(4.734217,  1.097051, -16.3), &contrail_main);
	AddExhaustStream (th_after, _V(6.070018,  1.076913, -16.3), &contrail_main);

    AddExhaustStream (th_trail, _V(-12.41261, 0.8024065, -16.26509), &contrail_hover);
									//-9.796907,  0.3918755, -13.75534
    AddExhaustStream (th_trail, _V(12.41261, 0.8024065, -16.26509), &contrail_hover);
	//AddExhaustStream (th_trail, _V(3.7,0.1,-14.5), &contrail_hover);
	//AddExhaustStream (th_trail, _V(-3.7,0.1,-14.5), &contrail_hover);
  ///////////////////////////////////////////////////////////////
	
	th_rcs_up[0] = CreateThruster (_V(0,0,3), _V(0,1,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_rcs_up[1] = CreateThruster (_V(0,0,-3), _V(0,-1,0), PB_MAXRCSTH, hpr, PB_ISP);
	
	CreateThrusterGroup (th_rcs_up, 2, THGROUP_ATT_PITCHUP);
	
	th_rcs_down[0] = CreateThruster (_V(0,0,-3), _V(0,1,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_rcs_down[1] = CreateThruster (_V(0,0,3), _V(0,-1,0), PB_MAXRCSTH, hpr, PB_ISP);
	
	CreateThrusterGroup (th_rcs_down, 2, THGROUP_ATT_PITCHDOWN);
	
	th_rcs_left[0] = CreateThruster (_V(0,-3,0), _V(1,0,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_rcs_left[1] = CreateThruster (_V(0,3,0), _V(-1,0,0), PB_MAXRCSTH, hpr, PB_ISP);
	
	CreateThrusterGroup (th_rcs_left, 2, THGROUP_ATT_BANKLEFT);
	
	th_rcs_right[0] = CreateThruster (_V(0,3,0), _V(1,0,0), PB_MAXRCSTH, hpr, PB_ISP);
	th_rcs_right[1] = CreateThruster (_V(0,-3,0), _V(-1,0,0), PB_MAXRCSTH, hpr, PB_ISP);

	CreateThrusterGroup (th_rcs_right, 2, THGROUP_ATT_BANKRIGHT);

    th_rcs_yawl[0] = CreateThruster (_V(0,0,-3), _V(1,0,0), PB_MAXRCSTH, hpr, PB_ISP);
    th_rcs_yawl[1] = CreateThruster (_V(0,0,3), _V(-1,0,0), PB_MAXRCSTH, hpr, PB_ISP);

    CreateThrusterGroup (th_rcs_yawl, 2, THGROUP_ATT_YAWLEFT);

    th_rcs_yawr[0] = CreateThruster (_V(0,0,3), _V(1,0,0), PB_MAXRCSTH, hpr, PB_ISP);
    th_rcs_yawr[1] = CreateThruster (_V(0,0,-3), _V(-1,0,0), PB_MAXRCSTH, hpr, PB_ISP);

	CreateThrusterGroup (th_rcs_yawr, 2, THGROUP_ATT_YAWRIGHT);
	//////////////////////////////////////////////////////
    
    // Strobe lights
	
	//Blue beacon
	
	static VECTOR3 beacon1pos = { 12.37078,  1.108076, -14.94824};
								//  12.36488, 3.644471, -16.32908
	static VECTOR3 beacon1col = {0.043, 0.161, 0.992};
	
		beacon1.shape = (BEACONSHAPE_STAR);
		beacon1.pos = &beacon1pos;
		beacon1.col = &beacon1col;
		beacon1.size = (0.45);//0.22
		beacon1.falloff = (0.6);
		beacon1.period = (1.13);//1.13
		beacon1.duration = (1);//0.05
		beacon1.tofs = (0.6);
		beacon1.active = true;
		
		AddBeacon (&beacon1);
		
		//Red beacon
	
	static VECTOR3 beacon2pos = {-12.37078,  1.108076, -14.94824};
								// 12.36606 3.644471 -14.94824
	static VECTOR3 beacon2col = {0.988, 0.133, 0.133};
	
		beacon2.shape = (BEACONSHAPE_STAR);
		beacon2.pos = &beacon2pos;
		beacon2.col = &beacon2col;
		beacon2.size = (0.45);
		beacon2.falloff = (0.6);
		beacon2.period = (1.13);//1.13
		beacon2.duration = (1);//0.01
		beacon2.tofs = (0.6);
		beacon2.active = true;
		
		AddBeacon (&beacon2);

			//White strobe
	
	static VECTOR3 beacon3pos = {4.122388E-02, 3.782534, -31.05062};
								// 4.122388E-02, 3.782534, -31.05062
	static VECTOR3 beacon3col = {1,1,1};
	
		beacon3.shape = (BEACONSHAPE_STAR);
		beacon3.pos = &beacon3pos;
		beacon3.col = &beacon3col;
		beacon3.size = (0.33);
		beacon3.falloff = (0.6);
		beacon3.period = (1.13);
		beacon3.duration = (1);//0.01
		beacon3.tofs = (0.6);
		beacon3.active = true;
		
		AddBeacon (&beacon3);
		

       	//Orange strobe (L)
	
	static VECTOR3 beacon4pos = {-9.019858, 1.319256, -7.762111};
								// -9.019858, 1.319256, -7.762111
	static VECTOR3 beacon4col = {0.988, 0.333, 0.133};//0.988, 0.133, 0.133= red
	
		beacon4.shape = (BEACONSHAPE_DIFFUSE);
		beacon4.pos = &beacon4pos;
		beacon4.col = &beacon4col;
		beacon4.size = (0.66);//0.66
		beacon4.falloff = (0.6);
		beacon4.period = (1.13);
		beacon4.duration = (0.1);//0.01
		beacon4.tofs = (0.6);
		beacon4.active = true;
		
		AddBeacon (&beacon4);


			//Orange strobe (R)
	
	static VECTOR3 beacon5pos = {9.019858, 1.319256, -7.762111};
								// 
	static VECTOR3 beacon5col = {0.988, 0.333, 0.133};//0.988, 0.133, 0.133= red
	
		beacon5.shape = (BEACONSHAPE_DIFFUSE);
		beacon5.pos = &beacon5pos;
		beacon5.col = &beacon5col;
		beacon5.size = (0.66);
		beacon5.falloff = (0.6);
		beacon5.period = (1.13);
		beacon5.duration = (0.1);//0.01
		beacon5.tofs = (0.6);
		beacon5.active = true;
		
		AddBeacon (&beacon5);

			//Orange strobe (Rear)
	
	static VECTOR3 beacon6pos = {4.122388E-02, 3.782534, -31.05062};
								// -9.019858, 1.319256, -7.762111
	static VECTOR3 beacon6col = {0.988, 0.333, 0.133};//0.988, 0.133, 0.133= red
	
		beacon6.shape = (BEACONSHAPE_DIFFUSE);
		beacon6.pos = &beacon6pos;
		beacon6.col = &beacon6col;
		beacon6.size = (0.66);
		beacon6.falloff = (0.6);
		beacon6.period = (1.13);
		beacon6.duration = (0.1);//0.01
		beacon6.tofs = (0.6);
		beacon6.active = true;
		
		AddBeacon (&beacon6);

		//Landing Lights
		//Left wing
			static VECTOR3 beacon7pos = {-1.5033,  1.739632,  9.858963};
								// -1.5033,  1.739632,  9.858963
	static VECTOR3 beacon7col = {1,1,1};
	
		beacon7.shape = (BEACONSHAPE_STAR);
		beacon7.pos = &beacon7pos;
		beacon7.col = &beacon7col;
		beacon7.size = (0.3);
		beacon7.falloff = (0);
		beacon7.period = (0);
		beacon7.duration = (1);//0.01
		beacon7.tofs = (0.6);
		beacon7.active = true;
		
		AddBeacon (&beacon7);
			//Left gear
			static VECTOR3 beacon8pos = {-0.33582,  0.9119972,  12.64058};
								// -0.33582,  0.9119972,  12.64058
	static VECTOR3 beacon8col = {1,1,1};
	
		beacon8.shape = (BEACONSHAPE_STAR);
		beacon8.pos = &beacon8pos;
		beacon8.col = &beacon8col;
		beacon8.size = (0.3);
		beacon8.falloff = (0);
		beacon8.period = (0);
		beacon8.duration = (1);//0.01
		beacon8.tofs = (0.6);
		beacon8.active = true;
		
		AddBeacon (&beacon8);
			//Right wing
			static VECTOR3 beacon9pos = {1.5033,  1.739632,  9.858963};
								// 1.5033,  1.739632,  9.858963
	static VECTOR3 beacon9col = {1,1,1};
	
		beacon9.shape = (BEACONSHAPE_STAR);
		beacon9.pos = &beacon9pos;
		beacon9.col = &beacon9col;
		beacon9.size = (0.3);
		beacon9.falloff = (0);
		beacon9.period = (0);
		beacon9.duration = (1);//0.01
		beacon9.tofs = (0.6);
		beacon9.active = true;
		
		AddBeacon (&beacon9);
			//Right gear
			static VECTOR3 beacon10pos = {0.33582,  0.9119972,  12.64058};
								// 0.33582,  0.9119972,  12.64058
	static VECTOR3 beacon10col = {1,1,1};
	
		beacon10.shape = (BEACONSHAPE_STAR);
		beacon10.pos = &beacon10pos;
		beacon10.col = &beacon10col;
		beacon10.size = (0.3);
		beacon10.falloff = (0);
		beacon10.period = (0);
		beacon10.duration = (1);//0.01
		beacon10.tofs = (0.6);
		beacon10.active = true;
		
		AddBeacon (&beacon10);

	// visual specs
	
	AddMesh (f150);
   
	//SetMeshVisibilityMode( AddMesh (f150), MESHVIS_EXTERNAL|MESHVIS_VC );
  SetMeshVisibilityMode( AddMesh (f151,&offsetnose),MESHVIS_VC );
	SetMeshVisibilityMode( AddMesh (f152,&offset), MESHVIS_VC );//
	SetMeshVisibilityMode( AddMesh (f153,&offsetalt), MESHVIS_VC );
	SetMeshVisibilityMode( AddMesh (f154,&offsetbank), MESHVIS_VC );
    SetMeshVisibilityMode( AddMesh (f155,&offsetdirect), MESHVIS_VC );
	SetMeshVisibilityMode( AddMesh (f156,&offsetmach), MESHVIS_VC );
	SetMeshVisibilityMode( AddMesh (f157,&offsetspeed), MESHVIS_VC );
	SetMeshVisibilityMode( AddMesh (f158,&offsetcentre), MESHVIS_VC );
	//SetMeshVisibilityMode( AddMesh (f159,&offsetscreen), MESHVIS_VC );
	SetMeshVisibilityMode( AddMesh (f160,&offsetheight), MESHVIS_VC );
	SetMeshVisibilityMode( AddMesh (f161,&offsetbank2), MESHVIS_VC );
	SetMeshVisibilityMode( AddMesh (f180,&offsetvor), MESHVIS_VC );
	//SetMeshVisibilityMode( AddMesh (f181,&offsetautopilot), MESHVIS_VC );
	
    

}

// ==============================================================
// API callback interface
// ==============================================================

void ShuttlePB::clbkPostStep (double simt, double simdt, double mjd)

{
	SetAttitudeMode (RCS_NONE);
	if( oapiGetTimeAcceleration() > 10.0 ) oapiSetTimeAcceleration(10);
	
	double vsAirSpeed = GetAirspeed();
	//////////////////////////////////////////////
	if ( GroundContact() )
	{
	SetThrusterMax0 (th_rcs_up[0] ,0);
	SetThrusterMax0 (th_rcs_up[1] ,0);
	SetThrusterMax0 (th_rcs_down[0] ,0);
	SetThrusterMax0 (th_rcs_down[1] ,0);
	SetThrusterMax0 (th_rcs_left[0] ,0);
	SetThrusterMax0 (th_rcs_left[1] ,0);
	SetThrusterMax0 (th_rcs_right[0] ,0);
	SetThrusterMax0 (th_rcs_right[1] ,0);
	SetThrusterMax0 (th_rcs_yawl[0] ,0);
	SetThrusterMax0 (th_rcs_yawl[1] ,0);
	SetThrusterMax0 (th_rcs_yawr[0] ,0);
	SetThrusterMax0 (th_rcs_yawr[1] ,0);
	
}

    if ( !GroundContact() )
	{
	SetThrusterMax0 (th_rcs_up[0] ,9.9e4);
	SetThrusterMax0 (th_rcs_up[1] ,9.9e4);
	SetThrusterMax0 (th_rcs_down[0] ,9.9e4);
	SetThrusterMax0 (th_rcs_down[1] ,9.9e4);
	SetThrusterMax0 (th_rcs_left[0] ,9.9e4);
	SetThrusterMax0 (th_rcs_left[1] ,9.9e4);
	SetThrusterMax0 (th_rcs_right[0] ,9.9e4);
	SetThrusterMax0 (th_rcs_right[1] ,9.9e4);
	SetThrusterMax0 (th_rcs_yawl[0] ,9.9e4);
	SetThrusterMax0 (th_rcs_yawl[1] ,9.9e4);
	SetThrusterMax0 (th_rcs_yawr[0] ,9.9e4);
	SetThrusterMax0 (th_rcs_yawr[1] ,9.9e4);
	
}


	////////////////////////////////////////////
	
	
	
    //speed and altitude control
	
	if (GetAirspeed() >= 730) 
	{
		SetCW (999, 999, 999, 999);
		SetThrusterMax0 (th_main ,0);
		PlayVesselWave3(MySoundID,WARNING,LOOP);
StopVesselWave3(MySoundID,AFTER);
StopVesselWave3(MySoundID,ENG);
		
}

if (GetAltitude() >= 18500) 
	{
		SetCW (999, 999, 999, 999);
		SetThrusterMax0 (th_main ,0);
StopVesselWave3(MySoundID,AFTER);
StopVesselWave3(MySoundID,ENG);
	PlayVesselWave3(MySoundID,WARNING_ALT,LOOP);
}



if (GetAirspeed() < 730 && GetAltitude() < 18500 ) 
	{
		SetCW (0.3, 0.3, 0.67, 0.92);
		if (after == 1)
			if (GetThrusterLevel (th_main) > 0.5  )
		{
		SetThrusterMax0 (th_main ,7e5);//3.8e5//8e5//9e5//////217knts///////////////17e5//12e5//7e5//6e5
		SetThrusterMax0 (th_hover[0],9e5);//////////////////HOVER//th_hover[0],9e5
		SetThrusterMax0 (th_hover[1] ,9e5);//////////////////HOVER
		SetThrusterMax0 (th_after ,3e5);//////////////////AFTER//9e5//4e5//2e5

		SetThrusterLevel (th_after,1);
		SetThrusterGroupLevel (th_after,1);
		}
		if (after == 0)
		{
		SetThrusterMax0 (th_main ,7e5);//6.4e5//7.4e5///////////////10.4e5
		SetThrusterMax0 (th_hover[0],9e5);//////////////////HOVER//th_hover[0],9e5////////////////
		SetThrusterMax0 (th_hover[1] ,9e5);//////////////////HOVER
		SetThrusterMax0 (th_after ,0);//////////////////AFTER
		SetThrusterMax0 (th_retro ,-9.4e5);//////////////////

		SetThrusterLevel (th_after,0);
		SetThrusterGroupLevel (th_after,0);
		}
	StopVesselWave3(MySoundID,WARNING);
	StopVesselWave3(MySoundID,WARNING_ALT);
	//PlayVesselWave3(MySoundID,AFTER);
	//PlayVesselWave3(MySoundID,ENG);
}

//	double vsAirSpeed2 = (vsAirSpeed/1000)*3600;

 //////////////////////////////////////////////////////////
	
	// Engine sound
	
if (IsPlaying3(MySoundID,ENGSTART) == FALSE)
if (IsPlaying3(MySoundID,WARNING) == FALSE)
		if (GetThrusterLevel (th_main) > 0  ) 
{
	double pit = ((GetThrusterLevel (th_main)*6000));
	eng_pitch = 13000 + pit;
	
	if (eng_pitch < 11500 ) eng_pitch = 11500;
	
	if (eng_pitch > 22500 ) eng_pitch = 22500;
	
if ( oapiCameraInternal ())
		{
	PlayVesselWave3(MySoundID,ENG,LOOP,180,eng_pitch - 1000);
	PlayVesselWave3(MySoundID,ENGEXT,LOOP,180,eng_pitch - 1000);
		}
else
	//sprintf(oapiDebugString(),"anim %7.7f", eng_pitch );
		{		
	PlayVesselWave3(MySoundID,ENG,LOOP,(355*GetThrusterLevel (th_main)),eng_pitch);
	PlayVesselWave3(MySoundID,ENGEXT,LOOP,255,eng_pitch);
		}

}
		//retro sound
if (GetThrusterLevel (th_retro) > 0  ) 
{
	double pit = ((GetThrusterLevel (th_retro)*10000));//6000
	eng_pitch = 13000 + pit;
	
	if (eng_pitch < 11500 ) eng_pitch = 11500;
	
	if (eng_pitch > 28500 ) eng_pitch = 28500;//22500
	
if ( oapiCameraInternal ())
		{
	PlayVesselWave3(MySoundID,ENG,LOOP,210,eng_pitch );//180;1000
	//PlayVesselWave3(MySoundID,ENGEXT,LOOP,210,eng_pitch - 800);
		}
else
	//sprintf(oapiDebugString(),"anim %7.7f", eng_pitch );
		{		
	PlayVesselWave3(MySoundID,ENG,LOOP,255,eng_pitch);
	//PlayVesselWave3(MySoundID,ENGEXT,LOOP,255,eng_pitch);
		}

}
		/////////////////////////////////////
		// Power Gauge animation

        power_proc = GetThrusterLevel(th_main);
	
		SetAnimation( anim_power, power_proc );
		
	// EGT Gauge animation
		egtpower_proc = (GetThrusterLevel(th_main)/1.25);
		
		SetAnimation( egtanim_power, egtpower_proc );
		
		{if (after == 1 &&GetThrusterLevel (th_main) > 0.5)
		egtpower_proc = GetThrusterLevel(th_main);
		
		SetAnimation( egtanim_power, egtpower_proc );}
				
	//// % Gauge animation
		percentpower_proc = (GetThrusterLevel(th_main)/ (vsAirSpeed/60));
		
		SetAnimation( percentanim_power, percentpower_proc );
		
		{if (after == 1 &&GetThrusterLevel (th_main) > 0.5  )
		SetAnimation( percentanim_power, (percentpower_proc*1.25) );}


		// Fuel Guage Animation [1]
   
   fuel_proc = (GetFuelMass() + 55680)/55680;//GetFuelRate (void)//(GetFuelMass() + 55680)/55680;//= GetPropellantFlowrate (hpr1);

   i21 = fuel_proc / 2;//10000;
   
   if (i21 < 0) i21 = 0;
   
   if (i21 > 1) i21 = 1;
   
   SetAnimation (anim_fuel, i21);

   
   	// Fuel Guage Animation [2]
   
   fuel_proc = (GetPropellantMass (hpr1) + 20000)/20000;

   fuel_change = fuel_proc / 2;
   
   if (fuel_change <0) fuel_change = 0;
   
   if (fuel_change > 1) fuel_change = 1;
   
   SetAnimation (anim_fuel2, fuel_change);


	
	// CoG Meter Animation & CGShift
     
   //if (i22 > 10) i22 = 10;
 offsetcog.z = -(fuel_change - last_fuel_change);//*5
 
 {
 //ShiftCG(offsetcog);//ShiftCentreOfMass
 diff = (fuel_change - last_fuel_change)*5;
	 if (diff  > 15) diff = 15;
	 if (diff < 10) diff = 10;
 //EditAirfoil (AIRFOILHANDLE1,0x01,_V(0,0,(-0.061 - offsetcog.z*25)),VLiftCoeff, 16.5, 270, 2.266);//offsetcog.z
 
										//change2 = (GetPropellantMass (hpr1)- change1);
 if (fuel_change > last_fuel_change)
 
 SetControlSurfaceLevel (AIRCTRL_ELEVATORTRIM, (fuel_change/(change1/5)));//(GetPropellantMass (hpr1)+20000)/20000)//((fuel_change - last_fuel_change)*1000)
 
 //if (fuel_change == last_fuel_change)
 
 //SetControlSurfaceLevel (AIRCTRL_ELEVATORTRIM,0);

 if (fuel_change < last_fuel_change)
 
 SetControlSurfaceLevel (AIRCTRL_ELEVATORTRIM, (-fuel_change/change1));
/* 
 SetCameraOffset (_V(-1.5,0.51,(2.5 + offsetcog.z)));
 //ShiftMesh (0,offsetcog) ;
 ShiftMesh (1,offsetcog) ;
 ShiftMesh (2,offsetcog) ;
 ShiftMesh (3,offsetcog) ;
 ShiftMesh (4,offsetcog) ;
 ShiftMesh (5,offsetcog) ;
 ShiftMesh (6,offsetcog) ;
 ShiftMesh (7,offsetcog) ;
 ShiftMesh (8,offsetcog) ;
 ShiftMesh (9,offsetcog) ;
 ShiftMesh (10,offsetcog) ;
 ShiftMesh (11,offsetcog) ;
 ShiftMesh (12,offsetcog) ;
 ShiftMesh (13,offsetcog) ;
 
 */
 //SetMeshVisibilityMode( AddMesh (f152,&offset), MESHVIS_VC );//
   //CreateAirfoil (LIFT_VERTICAL, _V(0,0,(fuel_change - last_fuel_change))) ;

  // if (fuel_change > last_fuel_change) //ShiftCG (offsetcog);
   //if (fuel_change < last_fuel_change)// ShiftCG (-offsetcog);
  change2 = change1 ;
 change1 = (GetPropellantMass (hpr1))/100;
  last_fuel_change = fuel_change;
}		
	//if (fuel_change > 0)
{
	meter = fuel_change ;
SetAnimation (anim_cogmeter, meter);

}	

	//////////////////////////////////////////
   // Fuel Guage Animation[3]
   
   fuel_proc = (GetPropellantMass (hpr2) + 20000)/20000; 

   i23 = fuel_proc / 2;
   
   if (i23 < 0) i23 = 0;
   
   if (i23 > 1) i23 = 1;
   
   SetAnimation (anim_fuel3, i23);

   // Fuel Guage Animation[4]
   
   fuel_proc = (GetPropellantMass (hpr3) + 20000)/20000;

   i24 = fuel_proc / 2;
   
   if (i24 < 0) i24 = 0;
   
   if (i24 > 1) i24 = 1;
   
   SetAnimation (anim_fuel4, i24);
   ///


		{		//// Afterburner
    if (GetThrusterLevel (th_main) > 0.5  ) // added &&GetAirspeed() < 610 &&GetAltitude() < 18500
		if (IsPlaying3(MySoundID,WARNING) == FALSE)
		if (after == 1 ) 
	{
	if ( oapiCameraInternal ())
		{
	PlayVesselWave3(MySoundID,AFTER,LOOP,160,eng_pitch);
		}
else
	PlayVesselWave3(MySoundID,AFTER,LOOP,215,eng_pitch);
	}
		if (after == 0) 
		{
		StopVesselWave3(MySoundID,AFTER);
		}
	
}

	double vsAirSpeed2 = (vsAirSpeed/1000)*3600;
	//Ground Steering
    
    if (vsAirSpeed > 0.333 && vsAirSpeed < 99) {
    if (GroundContact () ) Steering();
}
    
    //aoa = GetAOA();
    
    //sprintf(oapiDebugString(),"anim %2.2f", aoa );
    
  

    //Anims 
    
    if (iop > 1)iop=0;
    
    if (vsAirSpeed > 0) {
    
	double aspeed = vsAirSpeed;
    if (iop > 1)iop=0;
    if (vsAirSpeed > 30) aspeed = 30; 
    iop = iop + (aspeed /300);
     
    if (vsAirSpeed ==0) iop=0;
    
    
    if ( GroundContact() && gear_proc < 0.05) SetAnimation (anim_wheel, iop);
    

   }
	   
   if (!GroundContact() && gear_proc < 1.0)
   {
	   tpp = 0.5;
	   SetAnimation( anim_turn, tpp );
}

   // Front Gear Turn Anims
   if (GroundContact())
   {
	   
   tpp = (GetControlSurfaceLevel (AIRCTRL_RUDDER) +1) *0.5;
   if (!GroundContact())tpp = 0.5;
   SetAnimation( anim_turn, tpp );
   
}
	
// Gear animations


   if( animactive && !GroundContact()) {
		if( animactive == 1 ) {
			gear_proc += 0.00142;//0.00242
			if( gear_proc > 1.0 ) {
				gear_proc = 1.0;
				animactive = 0;
			}
			if (animactive == 1)
			gear_cover -= 0.00442;
			if( gear_cover < 0.0 ) 
				gear_cover = 0.0;
				SetAnimation( anim_gearcover, gear_cover );
			
		}
		else  {
			gear_proc -= 0.00142;
			if( gear_proc < 0.0 ) {
				gear_proc = 0.0;
				animactive = 0;
			}
			if (animactive == 2)
				gear_cover += 0.00142;//0.00242
			if( gear_cover > 1.0 ) 
				gear_cover = 1.0;
				SetAnimation( anim_gearcover, gear_cover );
			
		}
		SetAnimation( anim_gear, gear_proc );
	}

   ////////////////////////////WARNINGS//////////////////////
  {if (GetAltitude()< 500 )
	   if (gear_proc == 1.0)
		   if (GetAOA() < 5)
		   //if (flaps == 0.0)
   PlayVesselWave3(MySoundID,TOO_LOW_T,NOLOOP,255);}
   
   {if (GetAltitude()< 200)
	   if (gear_proc == 1.0)
   PlayVesselWave3(MySoundID,PULL_UP,NOLOOP,255);}

   {if (GetAltitude()< 500)
	   if (gear_proc == 1.0)
		   if (GetPitch() < 4)
   PlayVesselWave3(MySoundID,TOO_LOW_G,NOLOOP,255);}

   {if (GetAltitude()> 1000)
	   if (gear_proc == 0.0)
   PlayVesselWave3(MySoundID,ATTFIRE,NOLOOP,255);}
/*
   {if (GetAltitude()< 900)
		if ( !GroundContact())
	   if (flaps == 0.0)
   PlayVesselWave3(MySoundID,TOO_LOW_F,NOLOOP,255);}
   */
///////////////////////////////////////////////////////////////
   // Wind Noise
   {if( vario > 0.0 )
	PlayVesselWave3(MySoundID,WIND,LOOP,((vsAirSpeed*2)*(vario*2)));
   SoundOptionOnOff3(MySoundID,PLAYWINDAIRSPEED,TRUE);}
     
   // Variable Geometry

   if( animactive5 ) {PlayVesselWave3(MySoundID,BRAKE,NOLOOP,255);
		if( animactive5 == 1 ) {
			if  (GetAirspeed() <139)//safe speed
			
			vario += 0.006;
			if( vario > 1.0 ) {
				vario = 1.0;
				animactive5 = 0;
			}
	
		}
		else  {
			vario -= 0.006;
			if( vario < 0.0 ) {
				vario = 0.0;
				animactive5 = 0;
				SoundOptionOnOff3(MySoundID,PLAYWINDAIRSPEED, FALSE);
				
			}
		}
		SetAnimation( anim_vario, vario );
		SetAnimation( anim_vario1, vario );
		SetAnimation( anim_variolever, vario );
		SetAnimation( anim_varioVC, vario );
		}
   ///////////////////////////////////////////////////
	
if( animactive6 ) {
			if( animactive6 == 1 ) {
			if  (GetAirspeed() <139)//safe speed
				
				vario += 0.006;
			if( vario > 0.666 ) {//if( vario > 0.333 )
				vario = 0.666;
				animactive6 = 0;
			}
		
		}
		else  {
			vario -= 0.006;
			if( vario < 0.0 ) {
				vario = 0.0;
				animactive6 = 0;
				StopVesselWave3(MySoundID,WIND);
			}
		}
		SetAnimation( anim_vario, vario );
		SetAnimation( anim_vario1, vario );
		SetAnimation( anim_variolever, vario );
		SetAnimation( anim_varioVC, vario );
		}
			if( animactive7 ) {
			if( animactive7 == 1 ) {
				if  (GetAirspeed() <139)//safe speed
			vario += 0.006;
			if( vario > 0.8 ) {//if( vario > 0.666 )
				vario = 0.8;
				animactive7 = 0;
			}
	
		}

		else  {
			vario -= 0.006;
			if( vario < 0.666 ) {/////////////////
				vario = 0.666;
				animactive7 = 0;
			}
		}
		SetAnimation( anim_vario, vario );
		SetAnimation( anim_vario1, vario );
		SetAnimation( anim_variolever, vario );
		SetAnimation( anim_varioVC, vario );
	}
	
			if( animactive8 ) {
			if( animactive8 == 1 ) {
			if  (GetAirspeed() <139)//safe speed
				
				vario += 0.006;
			if( vario > 1 ) {
				vario = 1;
				animactive7 = 0;
			}
	
		}

		else  {
			vario -= 0.006;
			if( vario < 0.8 ) {///////////////
				vario = 0.8;
				animactive8 = 0;
			}
		}
		SetAnimation( anim_vario, vario );
		SetAnimation( anim_vario1, vario );
		SetAnimation( anim_variolever, vario );
		SetAnimation( anim_varioVC, vario );
	}
	

/*	
	// Gear Lever animations


   if( animactivel && !GroundContact()) {
		if( animactivel == 1 ) {
			gear_procl += 0.00242;
			if( gear_procl > 1.0 ) {
				gear_procl = 1.0;
				animactivel = 0;
			}
		}
		else  {
			gear_procl -= 0.00242;
			if( gear_procl < 0.0 ) {
				gear_procl = 0.0;
				animactivel = 0;
			}
		}
		SetAnimation( anim_gearlever, gear_procl );
	}

	*/
///*	

   // Speedbrake animations


   if( animactive2 ) {
		if( animactive2 == 1 ) {
			speedbrake += 0.006;
			if( speedbrake > 1.0 ) {
				speedbrake = 1.0;
				animactive2 = 0;
			}
		}
		else  {
			speedbrake -= 0.006;
			if( speedbrake < 0.0 ) {
				speedbrake = 0.0;
				animactive2 = 0;
			}
		}
		SetAnimation( anim_speedbrake, speedbrake );
	}

	

   
   // Landing lights


   if( animactive4 ) {PlayVesselWave3(MySoundID,BRAKE,NOLOOP,255);
		if( animactive4 == 1 ) {
			flaps += 0.06;
			if( flaps > 1.0 ) {
				flaps = 1.0;
				animactive4 = 0;
			}
		}
		else  {
			flaps -= 0.06;
			if( flaps < 0.0 ) {
				flaps = 0.0;
				animactive4 = 0;
			}
		}
		SetAnimation( anim_flaps, flaps );
	}
/*
   SetControlSurfaceLevel(AIRCTRL_FLAP,flaps);

  
*/

   
 if (Lights == 1 && switched == 1)
 {
	// beacon1.active = true;
	// beacon2.active = true;
	// beacon3.active = true;
	 beacon4.active = true;//orange left
	 beacon5.active = true;//orange right
	// beacon6.active = true;//orange rear
	 switched = 0;
	 //Lighting();
}

if (Lights == 0 && switched == 0)
{
	//beacon1.active = false;
	//beacon2.active = false;
	//beacon3.active = false;
	beacon4.active = false;
	beacon5.active = false;
	//beacon6.active = false;
    switched = 1;
    //Lighting();
}
if (flaps == 1)
{
	beacon7.active = true;
	beacon8.active = true;
	beacon9.active = true;
	beacon10.active = true;
}
if (flaps == 0)
{
	beacon7.active = false;
	beacon8.active = false;
	beacon9.active = false;
	beacon10.active = false;
}
///* 
///////////////////////////////////
// Pitch Guage Animation
    
   i25 = GetPitch();
   
   i26 = (i25 + 3) / 6;
   
   if (i26 < 0) i26 = 0;
   
   if (i26 > 1) i26 = 1;
   
   SetAnimation (anim_pitch, i26);

///////////////////////////////////
	// Horizon Bank Guage Animation
    
   i15 = GetBank();
   
   i16 = (i15 + 3) / 6;
   
   if (i16 < 0) i16 = 0;
   
   if (i16 > 1) i16 = 1;
   
   SetAnimation (anim_bank, i16);
   
///////////////////////////////////
// Speed Dial animation
   // Mach Number animation
 // mi27 = GetMachNumber();
   
 //  if (mi27 > 3.4) mi27 = 3.4;//600//3.3
   
//   if (mi27 < 0) mi27 = 0;
   
 //  mi28 = (-mi27 + 3.4)/3.4;//600
   
 //  if (mi28 < 0) mi28 = 0;
   
 //  if (mi28 > 1) mi28 = 1;
   
 //  SetAnimation (anim_machdial, mi28);

 mks3 = GetMachNumber()*89.5;

 mks4 = int (mks3);
      
     _gcvt (mks3,6,mks3buffer);//_gcvt (mks3,6,mks3buffer);
     
     string mstringOne2(mks3buffer);
   ///////////////////////////////////
   
 
         
     
     // Speed Dial Animation
     
     if (mks3 >= 0 )
     {

     string msis1 = mstringOne2.substr(0 + mss2 + mss3 + mss4 + mss5, 1) ;
       
     char const *mscString1 = msis1.c_str();
     
     msi1a = atol(mscString1);
     
    msi1 = msi1a * 0.1;
     
 }
 
 if (mks3 >= 10 ) 
 {
	 
     string msis2 = mstringOne2.substr(0 + mss3 + mss4 + mss5 , 1) ;
       
     char const *mscString2 = msis2.c_str();
     
     msi2a = atol(mscString2);
     
     msi2 = msi2a * 0.1;
     mss2 = 1;
 }
 
 if (mks3 >= 100 )
 {
     string msis3 = mstringOne2.substr(0 + mss4 + mss5, 1) ;
       
     char const *mscString3 = msis3.c_str();
     
     msi3a = atol(mscString3);
     
     msi3 = msi3a * 0.1;
     
     mss3 = 1;
 }
 
 if (mks3 >= 1000)
 {
     string msis4 = mstringOne2.substr(0 + mss5, 1) ;
       
     char const *mscString4 = msis4.c_str();
     
     msi4a = atol(mscString4);
     
     msi4 = msi4a * 0.1;
     
    mss4 = 1;
 }
 
 if (mks3 >= 10000)
 {
     string msis5 = mstringOne2.substr(0, 1) ;
       
     char const *mscString5 = msis5.c_str();
     
     msi5a = atol(mscString5);
     
     msi5 = msi5a * 0.1;
     
     mss5 = 1;
}

      if(mks3<10)
      {
	      mss2=0;
	      msi2=0;
	     mss3=0;
	      msi3=0;
	      mss4=0;
	      msi4=0;
	     mss5=0;
	      msi5=0;
    }
         
    if(mks3<100)
      {
	     
	      mss3=0;
	      msi3=0;
	      mss4=0;
	      msi4=0;
	      mss5=0;
	      msi5=0;
    }
    
    if(mks3<1000)
      {
	      
	      mss4=0;
	     msi4=0;
	     mss5=0;
	      msi5=0;
    }
   
    if(mks3<10000)
      {
	     
	      mss5=0;
	      msi5=0;
	      
    }
    
    /*
   mi14=(mks3 *0.01 )- mdees;//* 0.01//0.0015//0.00333333
   
   if (mi14>=1)
   {
	   mdees = mdees + 1;
   }
   
   if (mi14 <= 0)
   {
	   mdees = mdees - 1;
	   
	   if (mdees < 0)mdees = 0;
   }
   
 */   
	//sprintf(oapiDebugString(),"force %2.2f", i1 );
	  
  ////////////////////////////////
	dmks3 = GetMachNumber();
	if (dmks3 > 3.4) dmks3 = 3.4;//600//3.3
   
   if (dmks3 < 0) dmks3 = 0;
   
   dmi14 = (-dmks3 + 3.4)/3.4;//600
   
   if (dmi14 < 0) dmi14 = 0;
   
   if (dmi14 > 1) dmi14 = 1;
   
   SetAnimation (anim_machdial, dmi14);
   ////////////////////////////
	
	//SetAnimation (anim_machdial0, msi);
	SetAnimation (anim_machdial1, msi1);
	SetAnimation (anim_machdial2, msi2);
	SetAnimation (anim_machdial3, msi3);
	//SetAnimation (anim_machdial4, msi4);
	//SetAnimation (anim_machdial5, msi5);
   //////////////////////////////
    //Anims 
    
     ks3 = (GetAirspeed()*1.9438445) ;//*1.9438445
    
     ks4 = int (ks3);
      
     _gcvt (ks3,6,ks3buffer);
     
     string stringOne2(ks3buffer);
   ///////////////////////////////////
	  // Speed Dial Animation
     
     if (ks3 >= 0 )
     {

     string sis1 = stringOne2.substr(0 + ss2 + ss3 + ss4 + ss5, 1) ;
       
     char const *scString1 = sis1.c_str();
     
     si1a = atol(scString1);
     
    si1 = si1a * 0.1;
     
 }
 
 if (ks3 >= 10 ) 
 {
	 
     string sis2 = stringOne2.substr(0 + ss3 + ss4 + ss5 , 1) ;
       
     char const *scString2 = sis2.c_str();
     
     si2a = atol(scString2);
     
     si2 = si2a * 0.1;
     ss2 = 1;
 }
 
 if (ks3 >= 100 )
 {
     string sis3 = stringOne2.substr(0 + ss4 + ss5, 1) ;
       
     char const *scString3 = sis3.c_str();
     
     si3a = atol(scString3);
     
     si3 = si3a * 0.1;
     
     ss3 = 1;
 }
 
 if (ks3 >= 1000)
 {
     string sis4 = stringOne2.substr(0 + ss5, 1) ;
       
     char const *scString4 = sis4.c_str();
     
     si4a = atol(scString4);
     
     si4 = si4a * 0.1;
     
    ss4 = 1;
 }
 
 if (ks3 >= 10000)
 {
     string sis5 = stringOne2.substr(0, 1) ;
       
     char const *scString5 = sis5.c_str();
     
     si5a = atol(scString5);
     
     si5 = si5a * 0.1;
     
     ss5 = 1;
}

      if(ks3<10)
      {
	      ss2=0;
	      si2=0;
	      ss3=0;
	      si3=0;
	      ss4=0;
	      si4=0;
	     ss5=0;
	      si5=0;
    }
         
    if(ks3<100)
      {
	     
	      ss3=0;
	      si3=0;
	      ss4=0;
	      si4=0;
	      ss5=0;
	      si5=0;
    }
    
    if(ks3<1000)
      {
	      
	      ss4=0;
	     si4=0;
	     ss5=0;
	      si5=0;
    }
   
    if(ks3<10000)
      {
	     
	      ss5=0;
	      si5=0;
	      
    }
    
 /*   
   si=(ks3 *0.01 )- dees;//* 0.01//0.0015//0.00333333
   
   if (si>=1)
   {
	   dees = dees + 1;
   }
   
   if (si <= 0)
   {
	   dees = dees - 1;
	   
	   if (dees < 0)dees = 0;
   }
   */
    
	//sprintf(oapiDebugString(),"force %2.2f", i1 );
	  
   if (ks3 > 600) ks3 = 600;//570;///600
   
   if (ks3 < 0) ks3 = 0;
   
   i14 = (-ks3 + 600)/600;
   
   if (i14 < 0) i14 = 0;
   
   if (i14 > 1) i14 = 1;
   
   SetAnimation (anim_wheels0, i14);//i14
	 ////////////////////////////////
	
	//SetAnimation (anim_wheels0, si);
	SetAnimation (anim_wheels1, si1);
	SetAnimation (anim_wheels2, si2);
	SetAnimation (anim_wheels3, si3);
	SetAnimation (anim_wheels4, si4);
	SetAnimation (anim_wheels5, si5);
	/////////////////////////////////////////////////////////
	 // Contrails
  
  if ( GetAirspeed() > 150 && GetAltitude()> 10000)
  
  {
	  SetThrusterMax0 (th_trail ,1);
	  SetThrusterLevel (th_trail ,1);
	  
  }
  
  if (GetAltitude()< 10000)
  
  {
	  SetThrusterMax0 (th_trail ,0);
	  SetThrusterLevel (th_trail ,0);
  }
  

  if ( GetAirspeed() < 150)
  
  {
	  SetThrusterMax0 (th_trail ,0);
	  SetThrusterLevel (th_trail ,0);
  }
   aoa = GetAOA();
    
    //Contrails 2
   i77 = aoa * 6;

  
  if ( GetAirspeed() >= 170 && i77 >= 1)
  
  {
	  SetThrusterMax0 (th_trail ,1);
	  SetThrusterLevel (th_trail ,1);
	  
  }
  
  if ( i77 < 1 && GetAirspeed() < 150 && GetAltitude() < 10000)
  
  {
	  SetThrusterMax0 (th_trail ,0);
	  SetThrusterLevel (th_trail ,0);
  }
  
	//Height Meter
   
  k3h = (GetAltitude()*3.28083)/100;//3280.83//(((GetAltitude()*3.28083)/100)+25)/25;
  {
	if (k3h == 0) iheight = 0;
	  if (k3h < 5)
	  iheight = k3h /20;//10
	
	if (iheight > 1) iheight = 1;
	if (iheight < 0) iheight = 0;
  }    
	SetAnimation (anim_hwheel, iheight);
	{
	if (k3h > 5)
	  i2height  = (k3h/35) ;//60
	
	if (i2height > 1) i2height = 1;
	if (i2height < 0) i2height = 0;
	}
	SetAnimation (anim_hwheel2, i2height);

	{
	if (k3h > 10)
	  i3height  = (k3h/50) ;//60
	
	if (i3height > 1) i3height = 1;
	if (i3height < 0) i3height = 0;
	}
	SetAnimation (anim_hwheel2, i3height);
	/////////////////////////////////aLTIMETER?????????????//////
   
    //Anims 
   // if ((GetAltitude()*3.28083) > (k3 *2)) k3 = 0  ;
	//if ((GetAltitude()*3.28083) > (k3 /2)) k3 = 0  ;
     k3 = (GetAltitude()*3.28083);//3280.83
    
     k4 = int (k3);
      
     _gcvt (k3,6,k3buffer);
     
     

   
     string stringOne(k3buffer);
     
     if (k3 >= 0 )
     {

     string is1 = stringOne.substr(0 + s2 + s3 + s4 + s5, 1) ;
       
     char const *cString1 = is1.c_str();
     
     i1a = atol(cString1);
     
    i1 = i1a * 0.1;
     
 }
 
 if (k3 >= 10 ) 
 {
	 
     string is2 = stringOne.substr(0 + s3 + s4 + s5 , 1) ;
       
     char const *cString2 = is2.c_str();
     
     i2a = atol(cString2);
     
     i2 = i2a * 0.1;
     s2 = 1;
 }
 
 if (k3 >= 100 )
 {
     string is3 = stringOne.substr(0 + s4 + s5, 1) ;
       
     char const *cString3 = is3.c_str();
     
     i3a = atol(cString3);
     
     i3 = i3a * 0.1;
     
     s3 = 1;
 }
 
 if (k3 >= 1000)
 {
     string is4 = stringOne.substr(0 + s5, 1) ;
       
     char const *cString4 = is4.c_str();
     
     i4a = atol(cString4);
     
     i4 = i4a * 0.1;
     
    s4 = 1;
 }
 
 if (k3 >= 10000)
 {
     string is5 = stringOne.substr(0, 1) ;
       
     char const *cString5 = is5.c_str();
     
    i5a = atol(cString5);
     
     i5 = i5a * 0.1;
     
     s5 = 1;
}

      if(k3<10)
      {
	      s2=0;
	      i2=0;
	      s3=0;
	      i3=0;
	      s4=0;
	      i4=0;
	      s5=0;
	      i5=0;
    }
         
    if(k3<100)
      {
	     
	      s3=0;
	      i3=0;
	      s4=0;
	      i4=0;
	      s5=0;
	      i5=0;
    }
    
    if(k3<1000)
      {
	      
	      s4=0;
	     i4=0;
	     s5=0;
	     i5=0;
    }
   
    if(k3<10000)
      {
	     
	      s5=0;
	      i5=0;
	      
    }
    
  
   i=(k3 * 0.01)- dee;
  
   if (i>=1)
   {
	   dee = dee + 1;
   }
   
   if (i <= 0)
   {
	   dee = dee - 1;
	   
	   if (dee < 0)dee = 0;
   }
    //ilast = i ;
    
	//sprintf(oapiDebugString(),"force %2.2f", i1 );
	
	
	SetAnimation (anim_wheel0, i);
	SetAnimation (anim_wheel1, i1);
	SetAnimation (anim_wheel2, i2);
	SetAnimation (anim_wheel3, i3);
	SetAnimation (anim_wheel4, i4);
	SetAnimation (anim_wheel5, i5);
	
	///////////////////////////////////////////////////
	

//*/

// AOA Slider Animation

    aoa = GetAOA();
    
    
   i7 = aoa *1.5;//1.5
   //if (i7 > 1) i7 = 1;
   //if (i7 < 0) i7 = 0;

   SetAnimation (anim_dial1, i7);

   // VSpeed Slider Animation

    VECTOR3 v;
	double vspd;
	if (GetHorizonAirspeedVector (v)) {
		
		vspd = ((v.y +24)/ 48);//vspd = ((v.y + 12) / 12);/20
		if (vspd  >1)  
		vspd = 1;
		if (vspd  <0)
			vspd = 0;
	}
    
    SetAnimation (anim_dial10, vspd);
   
   
   // Direction Dial Animation

   oapiGetFocusHeading(&dil);
    
   i9 = (dil / 6.25) + 0.001;
   
   //sprintf(oapiDebugString(),"hed %2.2f", dil );

   SetAnimation (anim_dial2, i9);

   //VOR dial animation
   oapiGetFocusHeading(&vdil);
    
   vi9 = (vdil / 6.25) + 0.001;
   
   //sprintf(oapiDebugString(),"hed %2.2f", dil );

   SetAnimation (anim_vordial2, vi9);
   /////////////////////////////////////
 /*   //Wheels Turn Right
   static UINT wLAGrp1[1] = {42};
   
   static MGROUP_ROTATE wlaileronr (1,wLAGrp1, 1, _V(1.490325,-0.893803,0.4785985), _V(0,0,1), (float)(-88*RAD));
   
    //Wheels Turn Left
   static UINT wLAGrp2[1] = {41};
   
   static MGROUP_ROTATE wlaileronl (1,wLAGrp2, 1, _V(-1.490325,-0.893803,0.4785985), _V(0,0,1), (float)(-88*RAD));
   
   
   anim_laileron = CreateAnimation (0.5);
   
   //AddAnimationComponent  (anim_laileron, 0, 1, &laileron);
   AddAnimationComponent  (anim_laileron, 0, 1, &wlaileronr);
   AddAnimationComponent  (anim_laileron, 0, 1, &wlaileronl);
   ///////////////////////////////////////////////////////////////
*/
}


//Ground Steering
//}

void ShuttlePB::Steering()
 {

	double pos = GetControlSurfaceLevel(AIRCTRL_RUDDER);
	double lev = 3e6 * pos ;//double lev = 1e6 * pos * GetAirspeed() / 10.0;

	if( oapiGetTimeAcceleration() > 10.0 )
		return;

	AddForce( _V( lev,0,0 ), _V( 0,0,3.33 ) );//AddForce( _V( lev,0,0 ), _V( 0,0,0.33 ) );
	AddForce( _V( -1.0*lev,0,0 ), _V( 0,0,-3.33 ) );//AddForce( _V( -1.0*lev,0,0 ), _V( 0,0,-0.33 ) );
	
}


// Lighting

void ShuttlePB::Lighting()
 
{
    if(Lights == 1)
    {
	
	SetMeshVisibilityMode( InsertMesh (f162,2,&offset), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f163,3,&offsetalt), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f164,4,&offsetbank), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f165,5,&offsetdirect), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f166,6,&offsetmach), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f167,7,&offsetspeed), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f168,8,&offsetcentre), MESHVIS_VC );
	//SetMeshVisibilityMode( InsertMesh (f159,9,&offsetscreen), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f170,10,&offsetheight), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f171,11,&offsetbank2), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f169,12,&offsetvor), MESHVIS_VC );
	//SetMeshVisibilityMode( InsertMesh (f172,13,&offsetautopilot), MESHVIS_VC );
	}

    if(Lights == 0)
    {
	
	SetMeshVisibilityMode( InsertMesh (f152,2,&offset), MESHVIS_VC );//
	SetMeshVisibilityMode( InsertMesh (f153,3,&offsetalt), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f154,4,&offsetbank), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f155,5,&offsetdirect), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f156,6,&offsetmach), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f157,7,&offsetspeed), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f158,8,&offsetcentre), MESHVIS_VC );
	//SetMeshVisibilityMode( InsertMesh (f159,9,&offsetscreen), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f160,10,&offsetheight), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f161,11,&offsetbank2), MESHVIS_VC );
	SetMeshVisibilityMode( InsertMesh (f180,12,&offsetvor), MESHVIS_VC );
	//SetMeshVisibilityMode( InsertMesh (f181,13,&offsetautopilot), MESHVIS_VC );
	
	}

}

// --------------------------------------------------------------
// Keyboard interface handler (buffered key events)
// --------------------------------------------------------------
int ShuttlePB::clbkConsumeBufferedKey (DWORD key, bool down, char *kstate)
{
	if (!down) return 0; // only process keydown events

	// if (KEYMOD_SHIFT (kstate)) {

		switch (key) {
		
	case OAPI_KEY_J: // Afterburners
		
		
		
			if( after == 0 )
			{
				after = 1;
				
				return 1;
			}
			
        if( after == 1)
			{
		
				after = 0;
				
				return 1;
			}
			
						
			return 1;

	case OAPI_KEY_B: // Speedbrake
		
		if( speedbrake > 0.5 )
					animactive2 = 2;
				else
					animactive2 = 1;

		PlayVesselWave3(MySoundID,BRAKE,NOLOOP,255);
		
			
			return 1;

case OAPI_KEY_G: // Gear
		
		if( gear_proc > 0.5 )
					animactive = 2;
				else
					//if  (GetAirspeed() <139)//safe speed///////////////////
					animactive = 1;

		if ( !GroundContact()) PlayVesselWave3(MySoundID,GEAR,NOLOOP,255);
		
		
		if( gear_procl > 0.5 )
					animactivel = 2;
				else
					animactivel = 1;

			
			return 1;
			
						 
		 case OAPI_KEY_V:// Variable geometry
		// if (variofirst > 0)
			 
					
			 if( vario == 1 )
					animactive5 = 2;
				else
				if  (GetAirspeed() <139)//safe speed
					animactive5 = 1;
 if  (GetAirspeed() >139)PlayVesselWave3(MySoundID,ATTFIRE,NOLOOP,255);
			 
					
			return 1;
			
		////////////////////////////////
			case OAPI_KEY_C: // Geom Down 10 deg
				PlayVesselWave3(MySoundID,BRAKE,NOLOOP,255);
				if  (GetAirspeed() <139)//safe speed
				if (variofirst < 0)
					variofirst = 0;
				if (variofirst > 2)
					variofirst = 2;
if  (GetAirspeed() <139)//safe speed
				if (variofirst == 0)
				animactive6 = 1;
 if  (GetAirspeed() >139)PlayVesselWave3(MySoundID,ATTFIRE,NOLOOP,255);
			 
if  (GetAirspeed() <139)//safe speed
				if (variofirst == 1)
				animactive7 = 1;
 if  (GetAirspeed() >139)PlayVesselWave3(MySoundID,ATTFIRE,NOLOOP,255);
			 
if  (GetAirspeed() <139)//safe speed
				if (variofirst == 2)
				animactive8 = 1;
 if  (GetAirspeed() >139)PlayVesselWave3(MySoundID,ATTFIRE,NOLOOP,255);
			 
		variofirst = (variofirst +1);
		
		return 1;
			/////////////////////////////////
			case OAPI_KEY_N: // Geom Up 10 deg
				PlayVesselWave3(MySoundID,BRAKE,NOLOOP,255);
				if (variofirst < 0)
					variofirst = 0;
				if (variofirst > 2)
					variofirst = 2;

				if (variofirst == 2)
				animactive8 = 2;

				if (variofirst == 1)
				animactive7 = 2;

				if (variofirst == 0)
				animactive6 = 2;

		variofirst = (variofirst -1);
		
		return 1;

				///////////////////////
	

			case OAPI_KEY_F: // Landing lights
		
		if( flaps > 0.5 )
					animactive4 = 2;
				else
					animactive4 = 1;
					
					first = 4;
					{
		PlayVesselWave3(MySoundID,BRAKE,NOLOOP,255);
					}
			
			return 1;
/*
case OAPI_KEY_D: // Flaps Down 10 deg
	
		flaps += 0.25;
		if (first <4)///////added
			if( flaps > 1.0 ) {
				flaps = 1.0;
				}
				
	    SetAnimation( anim_flaps, flaps );
	    
		exproc = flaps;
		first = (first +1);
		//first = 1;
		{
		PlayVesselWave3(MySoundID,FLAPS,NOLOOP,255);
		}		
			
			return 1;

				
case OAPI_KEY_S: // Flaps Up 10 deg
		
		flaps -= 0.25;
		if (first > 0.0)///////added
			if( flaps < 0.0 ) {
				flaps = 0.0;
				}
				
	    SetAnimation( anim_flaps, flaps );
	    
		exproc = flaps;
		first = (first -1);
		//first = 1;
		{
		PlayVesselWave3(MySoundID,FLAPS,NOLOOP,255);
		}
			
			return 1;
	*/		
		
			//KEYMOD_RSHIFT(buf)
			//if (KEYDOWN (kstate, OAPI_KEY_K)) {
			//case	OAPI_KEY_RSHIFT OAPI_KEY_K://
		case OAPI_KEY_K: // Lights		
		
		if( Lights == 0 )
		{
			Lights = 1;
			switched = 1;
					
			return 1;
}
			
		if( Lights == 1 )
		{
			Lights = 0;
			switched = 0;//1
					
			return 1;
					
			case OAPI_KEY_P: //HOLD_ALT
	i= NAVMODE_HOLDALT;
	{
		if (GetNavmodeState(i))//;
	return 0 ;
		}
	
	((int) NAVMODE_HOLDALT);
		
		return 1;

}
	
    //} 
		////////////////////////////////
				case OAPI_KEY_E: // Engine start/stop//////////////////////////SECTION ADDED
		
	if( Engine == 0 )
{
			Engine = 1;
			
			SetThrusterLevel (th_main,0.0015);
if ( oapiCameraInternal ())
	{
	PlayVesselWave3(MySoundID,ENGSTART,NOLOOP,220);
	//PlayVesselWave3(MySoundID,ENGEXT,LOOP,180,eng_pitch );
	}
else
	{
	PlayVesselWave3(MySoundID,ENGSTART,NOLOOP,255);
	//PlayVesselWave3(MySoundID,ENGEXT,LOOP,255,eng_pitch);		
	}			
			return 1;
}
		if( Engine == 1)//; ////////////; ///////////added?
		//Engine = 0;
		SetThrusterLevel (th_main,0);
		{
			StopVesselWave3(MySoundID,ENG);
			StopVesselWave3(MySoundID,ENGEXT);
			//StopVesselWave3(MySoundID,ENGINT);
		}					
	PlayVesselWave3(MySoundID,ENGSTOP,NOLOOP,255);///////////////////
		Engine = 0;///////////////////////////////////////////////////
	
    } 
	return 0;
}

//}//////////////////////////???????????????/
// Destructor
// --------------------------------------------------------------
ShuttlePB::~ShuttlePB ()
{
	
	delete pitch1;	
	delete wheel1;
	delete gwheel1;
	
}
void ShuttlePB::DefineAnimations(void)
{
	ANIMATIONCOMPONENT_HANDLE parent1;//added
	ANIMATIONCOMPONENT_HANDLE parent2;//added

   // Front Wheel
   static UINT WGrp1[1] = {99};//was 100
   
   gwheel1 = new MGROUP_ROTATE (0,WGrp1, 1, _V(4.261663E-02, -1.77868,  11.12268), _V(1,0,0), (float)(360*RAD));//-9.151995E-03
												//4.261663E-02, -1.77868,  11.12268
   //Turn Front Gear
   static UINT Trn1[1] = {98};
   
   static MGROUP_ROTATE turn1 (0,Trn1, 1, _V(4.261663E-02, -1.778759,  11.12506), _V(0,1,0), (float)(90*RAD));
												//  4.261663E-02, -1.778759,  11.12506
   
  //Rear left front Wheel
   static UINT WGrp3F[1] = {102};
   
   static MGROUP_ROTATE wheel2 (0,WGrp3F, 1, _V(4.849005E-02, -1.480318, -5.490253), _V(1,0,0), (float)(360*RAD));
												//4.849005E-02, -1.480318, -5.490253
   //Rear left rear Wheel
   static UINT WGrp3R[1] = {36};
   
   static MGROUP_ROTATE wheel3 (0,WGrp3R, 1, _V(3.347394, -1.497575, -7.242342), _V(1,0,0), (float)(360*RAD));
												//3.347394, -1.497575, -7.242342
   //Rear Right front wheel
   static UINT WGrp4F[1] = {104};
   
   static MGROUP_ROTATE wheel4 (0,WGrp4F, 1, _V(-4.849005E-02, -1.480318, -5.490253), _V(1,0,0), (float)(360*RAD));
												//-4.849005E-02, -1.480318, -5.490253
   //Rear Right rear wheel
   static UINT WGrp4R[1] = {46};
   
   static MGROUP_ROTATE wheel5 (0,WGrp4R, 1, _V(-3.347394, -1.497575, -7.242342), _V(1,0,0), (float)(360*RAD));
												//3.347394, -1.497575, -7.242342
   anim_turn = CreateAnimation (0.5);
   anim_wheel = CreateAnimation (0);
   
   parent1 = AddAnimationComponent  (anim_turn, 0, 1, &turn1);
   AddAnimationComponent  (anim_wheel, 0, 1, gwheel1,parent1);
   AddAnimationComponent  (anim_wheel, 0, 1, &wheel2);
   AddAnimationComponent  (anim_wheel, 0, 1, &wheel3);
   AddAnimationComponent  (anim_wheel, 0, 1, &wheel4);
   AddAnimationComponent  (anim_wheel, 0, 1, &wheel5);
   
   
   
   // Gear anims
  
   
   //Front Gear
   static UINT GGrp1[5] = {75,98,99,100,101};//{75,99,100,101,102}
   
   static MGROUP_ROTATE gear1 (0,GGrp1, 5, _V(4.272985E-02,  2.76204,  10.5772), _V(1,0,0), (float)(-90*RAD));//-140*RAD))
												// 4.272985E-02,  2.76204,  10.5772//0.7113725,  1.238479,  11.12015
   //Tail Gear
   static UINT GGrp8[4] = {88,105,106,107};//{19,45,9,37}
   
   static MGROUP_ROTATE gear8 (0,GGrp8, 4, _V(-0.148812,  1.596165, -23.87466), _V(1,0,0), (float)(40*RAD));//-140*RAD))
												// -0.148812,  1.596165, -23.87466
   //Rear Gear Left
   static UINT GGrp2[7] = {36,37,76,77,81,92,102};//{7,17,39,40,46,170}
   
   static MGROUP_ROTATE gear2 (0,GGrp2, 7, _V(-3.722016,  1.587335, -0.14501), _V(0,0,1), (float)(90*RAD));
											//					0,1,0//(2.5,0.4,-0.1)
   ///////////////////////////
static UINT GGrp10[1] = {91};
   static MGROUP_ROTATE Rstancheon (0, GGrp10, 1, _V(3.60785, -0.2726809, -0.14501), _V(0, 0, 1),(float)(80*RAD));

   static UINT GGrp11[1] = {77};
   static MGROUP_ROTATE Lstancheon (0, GGrp11, 1, _V(-3.515675, -0.2659666, -0.14501), _V(0, 0, 1),(float)(-80*RAD));

   //where:
//mesh mesh index
//grp array of mesh group indices
//ngrp number of mesh groups
//ref reference point for scaling origin
//scale scaling factors in x, y and z
   //////////////////////////
   //Rear Gear Right
   static UINT GGrp3[7] = {46,49,78,82,91,103,104};//{8,18,41,42,47,171}
   
   static MGROUP_ROTATE gear3 (0,GGrp3, 7, _V(3.778404,  1.558263, -0.14501), _V(0,0,1), (float)(-90*RAD));
											// 3.778404,  1.558263, -0.14501
   //Front Gear Cover Left
   static UINT GGrp41[1] = {70};//5
   
   static MGROUP_ROTATE gear41 (0,GGrp41, 1, _V(-0.5946761,  1.135309, 13.23393), _V(0,0,1), (float)(77*RAD));//85
   
   //Front Gear Cover Right						//-0.5946761,  1.135309, 13.23393
   static UINT GGrp42[1] = {86};//6
   
   static MGROUP_ROTATE gear42 (0,GGrp42, 1, _V(0.6648033,  1.135335, 10.88584), _V(0,0,1), (float)(-77*RAD));
												//  0.6648033,  1.135335, 10.88584
   /////////////////////////////////////////////////////
   //Front Gear Cover Left2
   static UINT GGrp412[1] = {70};//5
   
   static MGROUP_ROTATE gear412 (0,GGrp412, 1, _V(-0.5946761,  1.135309, 13.23393), _V(0,0,1), (float)(77*RAD));//85
   
   //Front Gear Cover Right2					//-0.5946761,  1.135309, 13.23393
   static UINT GGrp422[1] = {86};//6
   
   static MGROUP_ROTATE gear422 (0,GGrp422, 1, _V(0.6648033,  1.135335, 10.88584), _V(0,0,1), (float)(-77*RAD));
												//  0.6648033,  1.135335, 10.88584
   ///////////////////////////////////
   //Front Gear Cover Left/Rear
   static UINT GGrp43[1] = {71};//5
   
   static MGROUP_ROTATE gear43 (0,GGrp43, 1, _V(-0.5946761,  1.135309, 13.23393), _V(0,0,1), (float)(77*RAD));//85
   
   //Front Gear Cover Right/Rear						//-0.5946761,  1.135309, 13.23393
   static UINT GGrp44[1] = {90};//6
   
   static MGROUP_ROTATE gear44 (0,GGrp44, 1, _V(0.6648033,  1.135335, 10.88584), _V(0,0,1), (float)(-77*RAD));
												//  0.6648033,  1.135335, 10.88584
    //Tail Gear Cover Left
   static UINT GGrp45[1] = {34};//5
   
   static MGROUP_ROTATE gear9 (0,GGrp45, 1, _V( -0.2053404,  2.326852, -25.28834), _V(0,0,1), (float)(85*RAD));//77
												//-0.2053404,  2.326852, -25.28834
   //Tail Gear Cover Right						
   static UINT GGrp46[1] = {87};//6
   
   static MGROUP_ROTATE gear10 (0,GGrp46, 1, _V( 0.2890796,  2.326867, -25.28834), _V(0,0,1), (float)(-85*RAD));
   /////////////////////////////////////////////   0.2890796,  2.326867, -25.28834
   //Rear Left Gear Cover
   static UINT GGrp6[1] = {83};//43
   
   static MGROUP_ROTATE gear6 (0,GGrp6, 1, _V(-0.1035112,  0.7202498, -6.725667), _V(0,0,1), (float)(-80*RAD));//105
												//-0.1035112,  0.7202498, -6.725667
   //Rear Right Right Cover
   static UINT GGrp7[1] = {84};//44
   
   static MGROUP_ROTATE gear7 (0,GGrp7, 1, _V(0.1753793,  0.7206683, -6.72526), _V(0,0,1), (float)(80*RAD));
											// 0.1753793,  0.7206683, -6.72526
   
   
   //Rear Gear Right2
   //static UINT GGrp9[6] = {22,190,210,213,214,216};
   
  // static MGROUP_ROTATE gear9 (0,GGrp9, 6, _V(0.97,-1.1,-1.82), _V(1,0,0), (float)(-99*RAD));
   
   
   anim_gear = CreateAnimation (0);
   anim_gearcover = CreateAnimation (1);

   AddAnimationComponent  (anim_gearcover, 0.65, 1, &gear412);//front/front left close
   AddAnimationComponent  (anim_gearcover, 0.65, 1, &gear422);//front/front right close
   AddAnimationComponent  (anim_gear, 0.1, 0.5, &Rstancheon);
   AddAnimationComponent  (anim_gear, 0.1, 0.5, &Lstancheon);

   AddAnimationComponent  (anim_gear, 0.1, 0.9, &gear1);
   AddAnimationComponent  (anim_gear, 0.1, 0.9, &gear2);//0, 0.25
   AddAnimationComponent  (anim_gear, 0.1, 0.9, &gear3);
   AddAnimationComponent  (anim_gear, 0.65, 0.7, &gear41);//front/front left
   AddAnimationComponent  (anim_gear, 0.65, 0.7, &gear42);//front/front right
   AddAnimationComponent  (anim_gear, 0.6, 0.7, &gear43);//front Rear left
   AddAnimationComponent  (anim_gear, 0.6, 0.7, &gear44);//front Rear right
   AddAnimationComponent  (anim_gear, 0.8, 1, &gear6);//0.1, 0.2
   AddAnimationComponent  (anim_gear, 0.8, 1, &gear7);//0.6,0.7
   AddAnimationComponent  (anim_gear, 0.1, 0.9, &gear8);//tail gear
   AddAnimationComponent  (anim_gear, 0.65, 1, &gear9);//tail gear cover left
   AddAnimationComponent  (anim_gear, 0.65, 1, &gear10);//tail gear cover right
  
      
   //Variable Geometry VC
   static UINT VnGrp8[3] = {0,1,2};//10,172
   
   static MGROUP_ROTATE varioN8 (1,VnGrp8, 3, _V(4.8,0,17.5), _V(1,0,0), (float)(60*RAD));//-1,0,18
	
	anim_varioVC = CreateAnimation (0);
   
	AddAnimationComponent  (anim_varioVC, 0, 1, &varioN8);
   
   //Variable Geometry Nose
   static UINT VGrp8[1] = {64};//64
   
   static MGROUP_ROTATE vario8 (0,VGrp8, 1, _V(3.424075E-02,  1.205606,  21.72942), _V(1,0,0), (float)(7*RAD));//(-2,1.3,17.5)
												//3.424075E-02,  1.205606,  21.72942
	anim_vario = CreateAnimation (0);
   
	AddAnimationComponent  (anim_vario, 0.75, 1, &vario8);

	//Variable Geometry Visor
   static UINT VGrp81[1] = {167};//10,172
   
   //static MGROUP_ROTATE vario81 (0,VGrp81, 1, _V(-2,1.3,17.5), _V(1,0,0), (float)(10*RAD));//_V(-2,1.3,17.5), _V(1.5,0,0)-1,0,18//4.8,0,17.5//15*RAD
												//3.424075E-02,  3.032515,  22.97034
   static MGROUP_TRANSLATE vario81 (0,VGrp81, 1, _V(0,-0.65,0.75));
	anim_vario1 = CreateAnimation (0);
   
	AddAnimationComponent  (anim_vario1, 0, 1, &vario81);

	//Variable geometry Lever
	 static UINT VLGrp1[1] = {47};
   
   static MGROUP_TRANSLATE variolever (2,VLGrp1, 1, _V(0, -0.1296188, 0));
														// -0.1296188
   
   anim_variolever = CreateAnimation (0);
   
   AddAnimationComponent  (anim_variolever, 0, 1, &variolever);
   
   //Rudder left
   static UINT RGrp1[2] = {94,97};//was {94,98}
   
   static MGROUP_ROTATE rudderl (0,RGrp1, 2, _V( -4.105467E-02, 4.124976, -24.10214), _V(0,1,0), (float)(-8*RAD));//-6,1,-20
												//-7.495042E-02,  4.762607, -20.19879
   //Rudder right
   static UINT RGrp2[2] = {94,97};//was {94,98}
   
   static MGROUP_ROTATE rudderr (0,RGrp2, 2, _V( 4.105467E-02, 4.124976, -24.10214), _V(0,1,0), (float)(-8*RAD));//6,1,-20
   
   anim_rudder = CreateAnimation (0.5);
   
   AddAnimationComponent  (anim_rudder, 0.1, 0.9, &rudderl);
   AddAnimationComponent  (anim_rudder, 0.1, 0.9, &rudderr);
   /////////////////////
  /*  //Rudder left pedal
   static UINT RGrp1p[1] = {24};
   
   static MGROUP_ROTATE rudderlp (8,RGrp1p, 1, _V(-1.958291, -2.357657, 0.3888554), _V(1,0,0), (float)(-8*RAD));//-6,1,-20
												//-1.958291, -2.364664, 0.3888554
   //Rudder right pedal
   static UINT RGrp2p[1] = {25};
   
   static MGROUP_ROTATE rudderrp (8,RGrp2p, 1, _V(-0.781214, -2.357657, 0.3888554), _V(1,0,0), (float)(8*RAD));//6,1,-20
												//-0.781214, -2.357657, 0.3888554
  // anim_rudder = CreateAnimation (0.5);
   
   AddAnimationComponent  (anim_rudder, 0.1, 0.9, &rudderlp);
   AddAnimationComponent  (anim_rudder, 0.1, 0.9, &rudderrp);
  */ 
   
   //Elevator
   static UINT EGrp1[4] = {33,35,44,45};//115
   
   static MGROUP_ROTATE elevator (0,EGrp1, 4, _V(12.25345,  1.493592, -14.93827), _V(1,0,0), (float)(20*RAD));
									//12.25345,  1.493592, -14.93827
   
   anim_elevator = CreateAnimation (0.5);
   
   AddAnimationComponent  (anim_elevator, 0, 1, &elevator);
    //Stick Forward
   static UINT sEGrp1[4] = {39,40,41,42};//82,83,84,85
   
   static MGROUP_ROTATE selevator (2,sEGrp1, 4, _V(-1.474849, -2.434728,  0.3888554), _V(1,0,0), (float)(-20*RAD));
													//-1.474849, -2.434728,  0.3888554
   AddAnimationComponent  (anim_elevator, 0, 1, &selevator);
/*
    //2nd Sticks Forward
   static UINT sEGrp12[4] = {26,27,28,29};//82,83,84,85
   
   static MGROUP_ROTATE selevator2 (2,sEGrp12, 4, _V(4.272985E-02,  2.302971,  22.45673), _V(1,0,0), (float)(-20*RAD));
													//4.272985E-02,  2.302971,  22.45673
   AddAnimationComponent  (anim_elevator, 0, 1, &selevator2);
   */
   //Left Aleron
   static UINT LAGrp1[2] = {35,67};//
   
   static MGROUP_ROTATE laileron (0,LAGrp1, 2, _V(-11.87654,  1.071318, -14.97869), _V(1,0,0), (float)(13*RAD));//0,-0.1,-12.5
   
   
   anim_laileron = CreateAnimation (0.5);
   
   AddAnimationComponent  (anim_laileron, 0.1, 0.9, &laileron);
   ///////////////////////
   //Joystick Turn Right
   static UINT wLAGrp1[1] = {42};
   
   static MGROUP_ROTATE wlaileronr (2,wLAGrp1, 1, _V(1.490325,-0.893803,0.4785985), _V(0,0,1), (float)(-88*RAD));
   
    //Joystick Turn Left
   static UINT wLAGrp2[1] = {41};
   
   static MGROUP_ROTATE wlaileronl (2,wLAGrp2, 1, _V(-1.490325,-0.893803,0.4785985), _V(0,0,1), (float)(-88*RAD));
   ////////////////////////
   AddAnimationComponent  (anim_laileron, 0, 1, &wlaileronr);
   AddAnimationComponent  (anim_laileron, 0, 1, &wlaileronl);
  
   //Right Aleron
   static UINT RAGrp1[2] = {45,66};//2
   
   static MGROUP_ROTATE raileron (0,RAGrp1, 2, _V(11.87654,  1.071318, -14.97869), _V(1,0,0), (float)(-13*RAD));//0,-0.1,-12.5
   
   
   anim_raileron = CreateAnimation (0.5);
   
   AddAnimationComponent  (anim_raileron, 0.1, 0.9, &raileron);
   
   
   //Speedbrake
   static UINT SBGrp1[2] = {33,44,};//
   
   static MGROUP_ROTATE speedbrake (0,SBGrp1, 2, _V(12.25345,  1.493592, -14.93827), _V(1,0,0), (float)(35*RAD));
												//12.25345,  1.493592, -14.93827
   
   anim_speedbrake = CreateAnimation (0);
   
   AddAnimationComponent  (anim_speedbrake, 0, 1, &speedbrake);
   
  
  
   //Landing Lights animation
   
   //Left Landing lights
   static UINT FLGrp1[1] = {38};
   static UINT FLGrp2[1] = {50};

   static MGROUP_ROTATE lampslw (0,FLGrp1, 1, _V(-1.60319,  1.902848,  9.768086), _V(1,0,0), (float)(-100*RAD));//-2.34,-0.41,-3.62
											//-1.60319  1.902848  9.768086
   static MGROUP_ROTATE lampslg (0,FLGrp2, 1, _V(-0.33582,  1.104555,  12.44924), _V(1,0,0), (float)(-95*RAD));
   
   //Right Landing lights
   static UINT FRGrp1[1] = {39};
   static UINT FRGrp2[1] = {51};

   static MGROUP_ROTATE lampsrw (0,FRGrp1, 1, _V(1.60319,  1.902848,  9.768086), _V(1,0,0), (float)(-100*RAD));//0,-0.3,-12.4
											// 1.603493, 1.704835,  9.761728
   static MGROUP_ROTATE lampsrg (0,FRGrp2, 1, _V(0.33582,  1.104555,  12.44924), _V(1,0,0), (float)(-95*RAD));
   
   anim_flaps = CreateAnimation (0);
   
   AddAnimationComponent  (anim_flaps, 0, 1, &lampslw);
   AddAnimationComponent  (anim_flaps, 0, 1, &lampslg);
   AddAnimationComponent  (anim_flaps, 0, 1, &lampsrw);
   AddAnimationComponent  (anim_flaps, 0, 1, &lampsrg);
    
   
   //Height Meter
   
   static UINT HGrp0[1] = {1};
   
   static MGROUP_ROTATE hwheel0 (9,HGrp0, 1, _V(-2.598444E-04,  3.175881E-04, 1.249995E-03), _V(0,0,1), (float)(-360*RAD));
    static MGROUP_ROTATE hwheel01 (9,HGrp0, 1, _V(-2.598444E-04,  3.175881E-04, 1.249995E-03), _V(0,0,1), (float)(-300*RAD));
   
   anim_hwheel = CreateAnimation (0);
   anim_hwheel2 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_hwheel, 0, 0.5, &hwheel0);
   AddAnimationComponent  (anim_hwheel2, 0, 1, &hwheel0);
   
   
   
   // Altimeter Animations
   
   // Dial
   static UINT wWGrp0[1] = {1};
   
   static MGROUP_ROTATE wwheel0 (3,wWGrp0, 1, _V(0,0,0), _V(0,0,1), (float)(-360*RAD));
   
   
   anim_wheel0 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_wheel0, 0, 1, &wwheel0);
   
     // 1st dial from Left
   static UINT wWGrp1[10] = {23,24,25,26,27,28,29,30,31,32};
   
   static MGROUP_ROTATE wwheel1 (3,wWGrp1, 10, _V(6.562528E-02,  4.299587E-02,  1.414326E-03), _V(1,0,0), (float)(360*RAD));//0,7.199557e-03,0
												//6.562528E-02,  4.299587E-02,  1.414326E-03
   
   anim_wheel1 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_wheel1, 0, 1, &wwheel1);
   
   // 2nd dial from Left
   static UINT wWGrp2[10] = {13,14,15,16,17,18,19,20,21,22};
   
   static MGROUP_ROTATE wwheel2 (3,wWGrp2, 10, _V(3.620707E-02,  4.327875E-02,  1.414326E-03), _V(1,0,0), (float)(360*RAD));
												//3.620707E-02,  4.327875E-02,  1.414326E-03
   
   anim_wheel2 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_wheel2, 0, 1, &wwheel2);
   
   // 3rd dial from Left
   static UINT wWGrp3[10] = {3,4,5,6,7,8,9,10,11,12};
   
   static MGROUP_ROTATE wwheel3 (3,wWGrp3, 10, _V(3.620707E-02,  4.327875E-02,  1.414326E-03), _V(1,0,0), (float)(360*RAD));
												//3.620707E-02,  4.327875E-02,  1.414326E-03
   
   anim_wheel3 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_wheel3, 0, 1, &wwheel3);
   
   // 4th dial from Left
   static UINT wWGrp4[10] = {43,44,45,46,47,48,49,50,51,52};
   
   static MGROUP_ROTATE wwheel4 (3,wWGrp4, 10, _V(3.620707E-02,  4.271301E-02,  1.018322E-02), _V(1,0,0), (float)(360*RAD));
												//3.620707E-02,  4.271301E-02,  1.018322E-02
   
   anim_wheel4 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_wheel4, 0, 1, &wwheel4);
   
   // 5th dial from Left(Right)
   static UINT wWGrp5[10] = {33,34,35,36,37,38,39,40,41,42};
   
   static MGROUP_ROTATE wwheel5 (3,wWGrp5, 10, _V(3.620707E-02,  4.271301E-02, 1.046609E-02), _V(1,0,0), (float)(360*RAD));
												//3.620707E-02,  4.271301E-02, 1.046609E-02
   
   anim_wheel5 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_wheel5, 0, 1, &wwheel5);
   ///////////////////////////////////
     // Horizon Bank Guage Animations
   
   static UINT BAGrp0[1] = {8};
   
   static MGROUP_ROTATE bank2 (4,BAGrp0, 1, _V(0, -0.0665953,  1.892073E-02), _V(0,0,1), (float)(-360*RAD));
												//-2.024872E-05, -2.729194E-02, 1.952006E-02
   static UINT PAGrp1[1] = {7};
   
   pitch1 = new MGROUP_ROTATE (4,PAGrp1, 1, _V(0, -0.0665953,  1.892073E-02), _V(1,0,0), (float)(-360*RAD));
												//-2.024872E-05, -2.652164E-02,  1.889166E-02
												//-2.024872E-05, -2.658245E-02,  1.895247E-02
   
   anim_pitch = CreateAnimation (0.5);
   anim_bank = CreateAnimation (0.5);
   
   parent1 = AddAnimationComponent  (anim_bank, 0, 1, &bank2); 
  AddAnimationComponent  (anim_pitch, 0, 1, pitch1, parent1); 
  //anim_bank = CreateAnimation (0.5);
   ///////////////////////////////////
    // Speedmeter Animations
   
   // Dial
   static UINT SwWGrp0[1] = {1};
   
   static MGROUP_ROTATE Swwheel0 (7,SwWGrp0, 1, _V(0,0,0), _V(0,0,1), (float)(370*RAD));//370*RAD
   
   
   anim_wheels0 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_wheels0, 0, 0.9, &Swwheel0);//////????????///////////0.9
   
   // 1st dial from Left(Right)
   static UINT SwWGrp1[10] = {23,24,25,26,27,28,29,30,31,32};
   
   static MGROUP_ROTATE Swwheel1 (7,SwWGrp1, 10, _V(7.799334E-02,  6.042916E-02, -2.946882E-04), _V(1,0,0), (float)(360*RAD));//0,7.199557e-03,0
												//9.158468E-02,  6.001097E-02,  5.416988E-04 //6.562528E-02,  4.299587E-02,  1.414326E-03
												//7.799334E-02,  6.042916E-02, -2.946882E-04
   anim_wheels1 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_wheels1, 0, 1, &Swwheel1);
   
   // 2nd dial from Left
   static UINT SwWGrp2[10] = {13,14,15,16,17,18,19,20,21,22};
   
   static MGROUP_ROTATE Swwheel2 (7,SwWGrp2, 10, _V(5.122888E-02,5.959278E-02,1.663486E-04), _V(1,0,0), (float)(360*RAD));
												//5.122888E-02,  5.959278E-02,  1.235091E-04//5.081069E-02,  5.959278E-02,  1.235091E-04//5.081069E-02,  5.917459E-02,  1.235091E-04
												//0  5.708363E-02  2.675517E-03
   anim_wheels2 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_wheels2, 0, 1, &Swwheel2);
   
   // 3rd dial from Left
   static UINT SwWGrp3[10] = {3,4,5,6,7,8,9,10,11,12};
   
   static MGROUP_ROTATE Swwheel3 (7,SwWGrp3, 10, _V(5.003797E-02,  5.951278E-02,  3.482038E-05), _V(1,0,0), (float)(360*RAD));
												//5.003797E-02  5.951278E-02  3.482038E-05//3.620707E-02,  4.327875E-02,  1.414326E-03
   
   anim_wheels3 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_wheels3, 0, 1, &Swwheel3);
   
   // 4th dial from Left
   static UINT SwWGrp4[10] = {43,44,45,46,47,48,49,50,51,52};
   
   static MGROUP_ROTATE Swwheel4 (7,SwWGrp4, 10, _V(-3.508043E-02,  5.978354E-02,  1.249578E-02), _V(1,0,0), (float)(360*RAD));
												//-3.508043E-02,  5.978354E-02,  1.249578E-02
												//-3.508043E-02  5.936117E-02  1.207339E-02
   anim_wheels4 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_wheels4, 0, 1, &Swwheel4);
   
   // 5th dial from Left(Right)
   static UINT SwWGrp5[10] = {33,34,35,36,37,38,39,40,41,42};
   
   static MGROUP_ROTATE Swwheel5 (7,SwWGrp5, 10, _V(3.620707E-02,  4.271301E-02, 1.046609E-02), _V(1,0,0), (float)(360*RAD));
												//3.620707E-02,  4.271301E-02, 1.046609E-02
   
   anim_wheels5 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_wheels5, 0, 1, &Swwheel5);
   ////////////////////////////////
   // Mach Dial Animation
   static UINT d3Grp0[3] = {0,1,2};
   
   static MGROUP_ROTATE dial3 (6,d3Grp0, 3, _V(1.502813E-05,  1.502705E-05, 0), _V(0,0,1), (float)(360*RAD));
											// 1.502813E-05,  1.502705E-05, 0
   
   anim_machdial = CreateAnimation (0);
   
   AddAnimationComponent  (anim_machdial, 0, 0.84, &dial3);
   
   // 1st dial from (Right)
   static UINT MSwWGrp1[10] = {14,15,16,17,18,19,20,21,22,23};
   
   static MGROUP_ROTATE MSwwheel1 (6,MSwWGrp1, 10, _V(0,  3.332501E-02,  4.136676E-02), _V(1,0,0), (float)(360*RAD));//0,7.199557e-03,0
												//-5.781715E-02,  3.240937E-02,  4.102754E-02
												//0,  3.332501E-02,  4.136676E-02
   anim_machdial1 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_machdial1, 0, 1, &MSwwheel1);
   
   // 2nd dial from Left
   static UINT MSwWGrp2[10] = {4,5,6,7,8,9,10,11,12,13};
   
   static MGROUP_ROTATE MSwwheel2 (6,MSwWGrp2, 10, _V(0,  3.159384E-02,  4.454057E-02), _V(1,0,0), (float)(360*RAD));
												//-5.781883E-02,  0.0304965,  4.566013E-02
												//0,  3.159384E-02,  4.454057E-02
   anim_machdial2 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_machdial2, 0, 1, &MSwwheel2);
   
   // 3rd dial from Left
   static UINT MSwWGrp3[10] = {24,25,26,27,28,29,30,31,32,33};
   
   static MGROUP_ROTATE MSwwheel3 (6,MSwWGrp3, 10, _V(-8.295184E-02,  3.159384E-02,  0.0448291), _V(1,0,0), (float)(360*RAD));
												//-6.197101E-02,  3.049159E-02,  4.582645E-02
												//-8.295184E-02,  3.159384E-02,  0.0448291
   
   anim_machdial3 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_machdial3, 0, 1, &MSwwheel3);
   /////////////////////////////////////////////
  
   // AOA Slider Animations
   
   // Dial1
   static UINT dGrp0[1] = {48};
   
   //static MGROUP_ROTATE dial1 (2,dGrp0, 1, _V(0,0,0), _V(0,0,1), (float)(311*RAD));
   static MGROUP_TRANSLATE dial1 (2,dGrp0, 1, _V(0,0,-0.05));//-0.05
   
   anim_dial1 = CreateAnimation (0.5);
   
   AddAnimationComponent  (anim_dial1, 0, 1, &dial1);

   // Vert Speed Slider Animations
   
   // Dial10
   static UINT d10Grp0[1] = {49};
   
   static MGROUP_TRANSLATE dial10 (2,d10Grp0, 1, _V(0,0.4,0));

 //  static UINT d10Grp1[1] = {49};
   
  // static MGROUP_TRANSLATE dial11 (2,d10Grp1, 1, _V(0,0.4,0));
   
   anim_dial10 = CreateAnimation (0.5);
   
   AddAnimationComponent  (anim_dial10, 0, 1, &dial10);
  // AddAnimationComponent  (anim_dial10, 0.1, 0.9, &dial11);
   

    // Direction Dial Animations
   
   // Dial2
   static UINT d2Grp0[1] = {0};
   
   static MGROUP_ROTATE dial2 (5,d2Grp0, 1, _V(0,0,0), _V(0,0,1), (float)(360*RAD));
   
   
   anim_dial2 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_dial2, 0, 1, &dial2);

     // VOR Dial Animations
   
   // Dial
   static UINT VORd2Grp0[1] = {0};
   
   static MGROUP_ROTATE VORdial2 (11,VORd2Grp0, 1, _V(0,0,0), _V(0,0,1), (float)(360*RAD));
   
   
   anim_vordial2 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_vordial2, 0, 1, &VORdial2);
   
   
   // Gear Lever Animation
  /* 
   //Gear Lever in Cockpit
   static UINT Glev0[2] = {11,76};
   
   static MGROUP_ROTATE gearlev (2,Glev0, 2, _V(-0.2455866,0.127598,4.584907E-02), _V(1,0,0), (float)(41*RAD));
   
   anim_gearlever = CreateAnimation (0);
   
   AddAnimationComponent  (anim_gearlever, 0, 1, &gearlev);
*/
     // Power Lever Animation
   
		static UINT Pow0[11] = {28,29,30,31,32,33,34,35,36,37,38};
   
   static MGROUP_ROTATE powg (2,Pow0, 11, _V(0,-1.688894,-6.171025E-02), _V(1,0,0), (float)(50*RAD));
    
		//N2 Bank Gauges
		static UINT Pow1[1] = {2};
   
   static MGROUP_ROTATE powg1 (8,Pow1, 1, _V(-0.3905083,  0.3924776, -2.881487E-03), _V(0,0,1), (float)(-180*RAD));
											//-0.3905083,  0.3924776, -2.881487E-03
		static UINT Pow2[1] = {6};
   
   static MGROUP_ROTATE powg2 (8,Pow2, 1, _V(-0.1420597,  0.3929093, -2.881487E-03), _V(0,0,1), (float)(-180*RAD));
											//-0.1420597,  0.3929093, -2.881487E-03
		static UINT Pow3[1] = {8};
   
   static MGROUP_ROTATE powg3 (8,Pow3, 1, _V(0.1120461,  0.393005, -2.881487E-03), _V(0,0,1), (float)(-180*RAD));
											// 0.1120461,  0.393005, -2.881487E-03
		static UINT Pow4[1] = {4};
   
   static MGROUP_ROTATE powg4 (8,Pow4, 1, _V(0.3618834,  0.3930321, -2.881487E-03), _V(0,0,1), (float)(-180*RAD));
											// 0.3618834,  0.3930321, -2.881487E-03
		//N1 Bank Gauges
   static UINT N1Pow1[1] = {12};
   
   static MGROUP_ROTATE N1powg1 (8,N1Pow1, 1, _V(-0.3895668,  0.2029572, -2.881488E-03), _V(0,0,1), (float)(-180*RAD));
											//-0.3895668,  0.2029572, -2.881488E-03
		static UINT N1Pow2[1] = {16};
   
   static MGROUP_ROTATE N1powg2 (8,N1Pow2, 1, _V(-0.139533,  0.2005589, -2.881488E-03), _V(0,0,1), (float)(-180*RAD));
											//-0.139533,  0.2005589, -2.881488E-03
		static UINT N1Pow3[1] = {14};
   
   static MGROUP_ROTATE N1powg3 (8,N1Pow3, 1, _V(0.1144314,  0.2029235, -2.881488E-03), _V(0,0,1), (float)(-180*RAD));
											//  0.1144314,  0.2029235, -2.881488E-03
		static UINT N1Pow4[1] = {10};
   
   static MGROUP_ROTATE N1powg4 (8,N1Pow4, 1, _V(0.3622782,  0.2029101, -2.881488E-03), _V(0,0,1), (float)(-180*RAD));
											// 0.3622782,  0.2029101, -2.881488E-03
		
   //EGT Bank Gauges
		static UINT TPow1[1] = {26};
   
  static MGROUP_ROTATE Tpowg1 (8,TPow1, 1, _V(-0.3850357, -0.1820055, -2.881488E-03), _V(0,0,1), (float)(-180*RAD));
											//-0.3850357, -0.1820055, -2.881488E-03
   		static UINT TPow2[1] = {30};
   
   static MGROUP_ROTATE Tpowg2 (8,TPow2, 1, _V(-0.1370918, -0.1819387, -2.881488E-03), _V(0,0,1), (float)(-180*RAD));
											//-0.1370918, -0.1819387, -2.881488E-03
		static UINT TPow3[1] = {32};
   
   static MGROUP_ROTATE Tpowg3 (8,TPow3, 1, _V(0.1169357, -0.1819056, -2.881488E-03 ), _V(0,0,1), (float)(-180*RAD));
											// 0.1169357, -0.1819056, -2.881488E-03  
		static UINT TPow4[1] = {28};
   
   static MGROUP_ROTATE Tpowg4 (8,TPow4, 1, _V(0.3669076, -0.1818722, -2.881488E-03), _V(0,0,1), (float)(-180*RAD));
											// 0.3669076 -0.1818722 -2.881488E-03
   
	//Percent Bank Gauges
	static UINT pcPow1[1] = {36};
   
   static MGROUP_ROTATE pcpowg1 (8,pcPow1, 1, _V(-0.3869037, -0.371944, 0.341954), _V(0,0,1), (float)(-300*RAD));
											//-0.3869037, -0.371944, 0.341954
		static UINT pcPow2[1] = {40};
   
   static MGROUP_ROTATE pcpowg2 (8,pcPow2, 1, _V(-0.1370404, -0.3720921, 0.341954), _V(0,0,1), (float)(-300*RAD));
											//-0.1370404, -0.3720921, 0.341954
		static UINT pcPow3[1] = {38};
   
   static MGROUP_ROTATE pcpowg3 (8,pcPow3, 1, _V(0.1170844, -0.3720033, 0.341954 ), _V(0,0,1), (float)(-300*RAD));
											//  0.1170844, -0.3720033, 0.341954
		static UINT pcPow4[1] = {34};
   
   static MGROUP_ROTATE pcpowg4 (8,pcPow4, 1, _V(0.3649501, -0.3719886, 0.341954), _V(0,0,1), (float)(-300*RAD));
											//  0.3649501, -0.3719886, 0.341954
   

   anim_power = CreateAnimation (0);
   egtanim_power = CreateAnimation (0);
   percentanim_power = CreateAnimation (0);
   
   AddAnimationComponent  (anim_power, 0, 1, &powg);

   AddAnimationComponent  (anim_power, 0.1, 1, &powg1);
   AddAnimationComponent  (anim_power, 0.1, 1, &powg2);
   AddAnimationComponent  (anim_power, 0.1, 1, &powg3);
   AddAnimationComponent  (anim_power, 0.1, 1, &powg4);

   AddAnimationComponent  (anim_power, 0, 1, &N1powg1);
   AddAnimationComponent  (anim_power, 0, 1, &N1powg2);
   AddAnimationComponent  (anim_power, 0, 1, &N1powg3);
   AddAnimationComponent  (anim_power, 0, 1, &N1powg4);
   
   AddAnimationComponent  (egtanim_power, 0.2, 1, &Tpowg1);
   AddAnimationComponent  (egtanim_power, 0.2, 1, &Tpowg2);
   AddAnimationComponent  (egtanim_power, 0.2, 1, &Tpowg3);
   AddAnimationComponent  (egtanim_power, 0.2, 1, &Tpowg4);

   AddAnimationComponent  (percentanim_power, 0, 1, &pcpowg1);
   AddAnimationComponent  (percentanim_power, 0, 1, &pcpowg2);
   AddAnimationComponent  (percentanim_power, 0, 1, &pcpowg3);
   AddAnimationComponent  (percentanim_power, 0, 1, &pcpowg4);

    // Fuel Guage Animation
   
   static UINT Ful1[1] = {20};
   
   static MGROUP_ROTATE fulg1 (8,Ful1, 1, _V(-0.3895329,  8.058903E-03, -2.881488E-03), _V(0,0,1), (float)(-360*RAD));//-360*RAD
											//-0.3895329,  8.058903E-03, -2.881488E-03
   static UINT Ful2[1] = {24};
   
   static MGROUP_ROTATE fulg2 (8,Ful2, 1, _V(-0.1394992,  8.025082E-03, -2.881488E-03), _V(0,0,1), (float)(-360*RAD));//-36
											//-0.1394992,  8.025082E-03, -2.881488E-03
   static UINT Ful3[1] = {22};
   
   static MGROUP_ROTATE fulg3 (8,Ful3, 1, _V(0.1144992,  7.957349E-03, -2.881488E-03), _V(0,0,1), (float)(-360*RAD));//-36
											// 0.1144992,  7.957349E-03, -2.881488E-03
   static UINT Ful4[1] = {18};
   
   static MGROUP_ROTATE fulg4 (8,Ful4, 1, _V(0.3624313,  8.059006E-03, -2.881488E-03), _V(0,0,1), (float)(-360*RAD));//-36
											// 0.3624313,  8.059006E-03, -2.881488E-03
   anim_fuel = CreateAnimation (0);
    anim_fuel2 = CreateAnimation (0);
	 anim_fuel3 = CreateAnimation (0);
	  anim_fuel4 = CreateAnimation (0);
   
   AddAnimationComponent  (anim_fuel, 0, 1, &fulg1);
   AddAnimationComponent  (anim_fuel2, 0, 1, &fulg2);
   AddAnimationComponent  (anim_fuel3, 0, 1, &fulg3);
   AddAnimationComponent  (anim_fuel4, 0, 1, &fulg4);

    //CoG Meter
   static UINT CMGrp1[1] = {44};
   
   static MGROUP_TRANSLATE cogmeter (2,CMGrp1, 1, _V(0,0,-0.05));//0,0,-0.6
													//-0.966395, -0.8872414, 0.8155603
   
   anim_cogmeter = CreateAnimation (1);
   
   AddAnimationComponent  (anim_cogmeter, 0, 1, &cogmeter);

}
	

bool ShuttlePB::clbkLoadVC (int id)
{
	
	SetCameraOffset (_V(-1.5,0.81,2.5));//(-0.4,3.57,22//(-0.4,3.59,22)
	//offsetcog.z = (fuel_change - last_fuel_change)*80;
    SetCameraDefaultDirection (_V(0,0,1));

    SetCameraRotationRange (RAD*30, RAD*30, RAD*16, RAD*20);
	
	static VCHUDSPEC hud_pilot  = {1, 90,{0,0.13,4.44},0.5};
	
			
		static VCMFDSPEC mfds_left = {2, 43};
		static VCMFDSPEC mfds_right= {2, 45};
		static VCMFDSPEC mfds_user1 = {2, 46};
		
        oapiVCRegisterMFD (MFD_LEFT, &mfds_left);
        oapiVCRegisterMFD (MFD_RIGHT, &mfds_right);
        oapiVCRegisterMFD (MFD_USER1, &mfds_user1);
		oapiVCRegisterHUD (&hud_pilot);

		
	
	
 return true;

}
/*bool ShuttlePB::clbkLoadVC (int id1)
{
	
	SetCameraOffset (_V(-0.4,3.5,22));//(-0.4,3.5,22)(-1.5,0.81,2.5) -1.5,0.11,2.5//2.0//(-1.5,0.51,2.5)//(-1.5,0.71,2.5)
	//offsetcog.z = (fuel_change - last_fuel_change)*80;
    SetCameraDefaultDirection (_V(0,0,1));

    SetCameraRotationRange (RAD*40, RAD*36, RAD*16, RAD*26);
	
	static VCHUDSPEC hud_pilot  = {1, 90,{0,0.13,4.44},0.5};
	
			
		static VCMFDSPEC mfds_left = {2, 43};
		static VCMFDSPEC mfds_right= {2, 45};
		static VCMFDSPEC mfds_user1 = {2, 46};
		
        oapiVCRegisterMFD (MFD_LEFT, &mfds_left);
        oapiVCRegisterMFD (MFD_RIGHT, &mfds_right);
        oapiVCRegisterMFD (MFD_USER1, &mfds_user1);
		oapiVCRegisterHUD (&hud_pilot);

		
	
	
 return true;

}
*/
// --------------------------------------------------------------
// Vessel initialisation
// --------------------------------------------------------------
DLLCLBK VESSEL *ovcInit (OBJHANDLE hvessel, int flightmodel)
{
	return new ShuttlePB (hvessel, flightmodel);
}

// --------------------------------------------------------------
// Vessel cleanup
// --------------------------------------------------------------
DLLCLBK void ovcExit (VESSEL *vessel)
{
	if (vessel) delete (ShuttlePB*)vessel;
}
